% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_calc_cepstre.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99
% Modifi par C.S. le 17/05/04 : couleur des graphes gre par variable
% globale (COULEUR_GRAPH)
%
% Contenu : Calcule le spectre du cepstre  un
%           instant donn
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_calc_cepstre(pos_sb)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_calc_cepstre(instant)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_FECH ACOU_SIG ACOU_FEN_TMP ACOU_ORD_FFT ACOU_CEPS_VIS NUM_SYNC COL_SYNC IND_SYNC COULEUR_GRAPH

figNumber=watchon;

% Teste si le fichier acoustique a t charg
if isempty(ACOU_SIG)
  errordlg(' Fichier acoustique non charg','Erreur','on');
  watchoff(figNumber);
  return;
end

% Rcupre le signal acoustique
sig_cp = acou_fen_signal(pos_sb);

if ~isempty(sig_cp)
  ['cepstre  t = ',num2str(pos_sb)];
  
  b = [1 -0.7];    % filtre de pre-emphase du signal
  sig_cep = filter(b,1,sig_cp); % pre-emphase du signal

  % Fenetrage du signal, fft, log(fft)
  spec = fft(sig_cep.*ACOU_FEN_TMP,ACOU_ORD_FFT);
  ceps = real(ifft(log(abs(spec)),ACOU_ORD_FFT));  % calcul du cepstre fft de la trame

  % Calcule l'chelle des temps du cepstre en ms
  tps_ceps = (1:ACOU_ORD_FFT/2)*1/ACOU_FECH*1000;
  
  % Recherche du F0
  [amp,ind] = max(ceps(round(ACOU_ORD_FFT/100):ACOU_ORD_FFT/2));
  t0 = tps_ceps(ind-1+round(ACOU_ORD_FFT/100));
  f0 = 1000/t0;

  % filtrage du cepstre ACOU_CEPS_VIS
  % Pour 1 ms, il faut ACOU_FECH/1000 points
  % Suivant sexe : ACOU_CEPS_VIS*(ACOU_FECH/1000) points
  NP = round(ACOU_CEPS_VIS*(ACOU_FECH/1000));
  ham_filt = hamming(NP*2); % fenetre de hamming pour filtrage BF du cepstre
  filt1 = [ham_filt(NP+1:2*NP) ; zeros(ACOU_ORD_FFT-2*NP-1,1) ; 0 ; ham_filt(1:NP)]; 
  % filtre de la fenetre de hamming
  % le zero et les indices correspondent a la repartition disymtrique (dcale) 
  % de la fft de la trame sur le cercle unit (voir plus haut)
  filt2 = [0.3 ; 0.45 ; 0.85 ; ones(ACOU_ORD_FFT-6,1) ; 1 ; 0.85 ; 0.45];

  % filtre sur les premiers coefficients du cepstre
  ceps_filt = ceps.*filt1.*filt2; % filtrage du cepstre

  % repassage dans le domaine des frequences
  ceps_filt = 20*log(abs(fft(ceps_filt)));

  % Calcule l'axe des frequences
  f = 0 : ACOU_FECH/ACOU_ORD_FFT : ACOU_FECH/2-1;
  
  % Affichage
  figure(NUM_SYNC);
  subplot(1,COL_SYNC,IND_SYNC);
  plot(f,ceps_filt(1:ACOU_ORD_FFT/2),'Color',COULEUR_GRAPH);
  grid on;
  buf = sprintf('Spectre du cepstre  t =%6.2f s',pos_sb);
% Attention ne pas changer cette couleur
% sinon la modification d'chelle marchera moins bien
% cf. modif_echelle.m
  title(buf,'Color','g'); %le titre est crit en green
  xlabel('Frquence Hz');
  ylabel('Amplitude dB');
  ylim = get(gca,'Ylim');
  xlim = get(gca,'Xlim'); 

  buf = sprintf('F0=%6.2f Hz',f0);
  text(xlim(2),ylim(2),buf,'Color',COULEUR_GRAPH,...
      'VerticalAlignment','top','HorizontalAlignment','right');

  % Incrmente l'index des subplots
  if IND_SYNC == COL_SYNC
    IND_SYNC = 1;
  else
    IND_SYNC = IND_SYNC + 1;
  end

end

watchoff(figNumber);

