% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_filtres.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99
% Contenu : Filtrage et affichage du signal
%           acoustique
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_filtres(num,fc)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 2
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_filtre(type_filtre, Fc)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_SIG ACOU_SIG_CUT ACOU_FECH ACOU_TPS ACOU_TPS_CUT NUM_FEN

figNumber=watchon;

% Test si le fichier acoustique a t charg
if isempty(ACOU_SIG)
  errordlg(' Fichier acoustique non charg','Erreur','on');
  watchoff(figNumber);
  return;
end

% si le signal a t coup, prendre le signal coup. 
if ~isempty(ACOU_SIG_CUT)
  sig = ACOU_SIG_CUT;
  temps = ACOU_TPS_CUT;
else
  sig = ACOU_SIG;
  temps = ACOU_TPS;
end

% Si aucune fenetre n'a t ouverte, on ouvre celle par dfaut
if NUM_FEN == 0
  fenetre(1,4,[20 90],[450 650],'Fenetre Principale');
end

if num == 1
  sig_filtre = acou_high_pass(sig,ACOU_FECH,fc);
  % Affichage
  if ~isempty(ACOU_SIG_CUT)
     trace_graphe(sig_filtre,temps,'ACOU FILT PH (aprs coupe)', '-', [ 1 1 0]);
  else
     trace_graphe(sig_filtre,temps,'ACOU FILT PH', '-', [ 1 1 0]);
  end
  
elseif num == 2
  sig_filtre = acou_low_pass(sig,ACOU_FECH,fc);

  % Affichage
  if ~isempty(ACOU_SIG_CUT)
     trace_graphe(sig_filtre,temps,'ACOU FILT PB (aprs coupe)', '-', [ 1 1 0]);
  else
     trace_graphe(sig_filtre,temps,'ACOU FILT PB', '-', [ 1 1 0]);
  end
  
elseif num == 3
  sig_filtre = filtre_remez(sig, ACOU_FECH);
  
  % Affichage
  if ~isempty(ACOU_SIG_CUT)
     trace_graphe(sig_filtre,temps,'ACOU FILT PH Remez (aprs coupe)', '-', [ 1 1 0]);
  else
     trace_graphe(sig_filtre,temps,'ACOU FILT PH Remez', '-', [ 1 1 0]);
  end

end

watchoff(figNumber);
