% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_ouv_epg.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 28.03.02
% Contenu : Ouverture et lecture du fichier
%           .nsp (EPG).
%           Ce fichier contient dans une premiere
%           partie les donnes acoustiques puis les 
%           donnes articulatoires.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function[data_epg,data_acou,temps_acou,temps_epg] =  acou_ouv_epg(nomfic)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : acou_ouv_epg(nomfic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global EPG_NB_ELEC ACOU_FECH EPG_FECH

% Initialisation
data = [];

if ACOU_FECH == 0
  errordlg(' Veuillez spcifier la frquence d''chantillonnage !','Erreur','on');
  return;
end

%=================================
% Ouverture du fichier en lecture
%=================================
% Ouverture du fichier binaire avec le format native (Matlab 6)

% Attention avec Matlab 4
% Ouverture avec le format :
% IEEE floating point with little-endian byte ordering
% fid = fopen(nomfic,'r','ieee-le');

fid = fopen(nomfic,'r','n');
if fid == -1   
  errordlg([' Fichier ',nomfic,' introuvable'],'Rsultat','on');
  return;
else

  %=================================
  % Lecture des donnes acoustiques
  %=================================
  % Ces donnes sont stockes  partir du 108e octet
  % Il y a d'abord une en-tete donnant qqs infos
  % sur les donnes acoustiques.
  % Cette en-tete commence par le mot-clef 'SDA_'
  % Elle donne ensuite la longueur des donnes acous. (en octets).
  % A la suite de ca, on peut lire les donnes acous sur des shorts.

  fseek(fid,108,-1);
  string = fscanf(fid,'%c',4);
  if strcmp(string,'SDA_')
    fseek(fid,112,-1);
    taille_acou = fread(fid,1,'long');
    data_acou = fread(fid,taille_acou/2,'short');
    temps_acou= 0 : 1/ACOU_FECH : (taille_acou/2-1)/ACOU_FECH;
  else
    errordlg([' Fichier ',nomfic,' nom conforme'],'Rsultat','on');
    fclose(fid);
    return
  end 

  %=================================
  % Lecture des donnes EPG
  %================================= 
  % Ces donnes sont stockes aprs les donnes acoustiques
  % Il y a d'abord une en-tete donnant qqs infos
  % sur les donnes EPG.
  % Cette en-tete commence par le mot-clef 'PALA'
  % Il se peut que les donnes EPG soit places aprs 
  % des donnes sur la gomtrie du palais 
  % (qui viennent aprs l'en-tete PREF).
  % Aprs ca, on a ensuite la longueur des donnes EPG.

  fseek(fid,taille_acou+116,-1);
  string = fscanf(fid,'%c',4);
  if strcmp(string,'PALA')
    fseek(fid,taille_acou+120,-1);
    taille_pala = fread(fid,1,'long');
  elseif strcmp(string,'PREF')
    fseek(fid,taille_acou+520,-1);
    taille_pala = fread(fid,1,'long');
  else
    errordlg([' Fichier ',nomfic,' nom conforme'],'Rsultat','on');
    fclose(fid);
    return
  end  

  % Nombre d'chantillons par voie au cours du temps, sachant
  % qu'il faut 12 octets pour stocker les valeurs 
  % des 96 voies  un instant donn (12 * 8 = 96)
  % octet 1 : voie8 voie7 voie6 voie5 voie4 voie3 voie2 voie1 
  % ....
  % octet 12 : voie96 voie95 voie94 voie93 voie92 voie91 voie90 voie89 

  epg_size = taille_pala/12;

  % Toutes les valeurs au cours du temps sont  la suite
  for i=1 : taille_pala
      temp = fread(fid,8,'ubit1');
      
      % Attention avec Matlab 4
      % le poids fort correspond  la voie de numro le plus lev
      %data = [data;temp(8:-1:1)];
      
      % Avec Matlab 6, c'est stock dans le bon ordre.
      data = [data;temp(1:1:8)];
  end

  %======================= 
  % Fermeture du fichier
  %=======================
  fclose(fid);

  %==============================================
  % Mise en forme :EPG_NB_ELEC *  nb chantillons
  %==============================================
  data_epg = reshape(data,EPG_NB_ELEC,epg_size);
  temps_epg = 0 : 1/EPG_FECH : (epg_size-1)/EPG_FECH; 

  %==============================
  % Lecture du fichier .usr
  % qui contient les informations 
  % sur les correspondances entre
  % les voies et les lectrodes
  % ainsi que les infos sur la
  % gomtrie du palais artificiel
  %==============================
  epg_ouv_elec;
end
