% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : acou_spectro.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Dernire modification par H. Loevenbruck 12.09.02
% Contenu : Calcul et affichage du sonagramme
% du signal acoustique contenu ds le subplot courant
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function acou_spectro

global ACOU_ORD_FFT ACOU_FEN_TMP ACOU_OVER_FEN ACOU_SIG ACOU_SIG_CUT ACOU_FECH CURSEUR
global NB_LIG NB_COL NUM_FEN INDEX SUPERPOSE ACOU_SPECTRO ACOU_NOM_FIC ACOU_TYP_FIC

figNumber=watchon;

% Test si le fichier acoustique a t charg
if isempty(ACOU_SIG)
  errordlg(' Fichier acoustique non charg','Erreur','on');
  watchoff(figNumber);
  return;
end

% si le signal a t coup, prendre le signal coup. 
if ~isempty(ACOU_SIG_CUT)
   sig = ACOU_SIG_CUT;
else 
  sig = ACOU_SIG;
end

% Calcul du sonagramme
% si ACOU_FEN_TMP est un scalaire : SPECGRAM uses a Hanning window of that length
% ACOU_OVER_FEN is the number of samples the sections of sig overlap
    
[sonagram,freq,tps] = ...
    specgram(sig,ACOU_ORD_FFT,ACOU_FECH,ACOU_FEN_TMP,ACOU_OVER_FEN);
ACOU_SPECTRO = 20*log10(abs(sonagram));
Esp=30;
emph = [0:Esp/(length(freq)-1):Esp]';
sonag = ACOU_SPECTRO + emph*ones(1,length(tps));

% Si aucune fenetre n'a t ouverte, on ouvre celle par defaut
if NUM_FEN == 0
  fenetre(1,4,[20 90],[450 650],'Fenetre Principale');
end 

% Affichage
figure(NUM_FEN);
hsub = subplot(NB_LIG+1,NB_COL,INDEX);
if SUPERPOSE
  hold on
else 
  hold off
end
imagesc(tps,freq,sonag);
axis xy;
asp=32;
g1=[ones(1,asp),1-1/asp:-1/asp:0]';
colormap([g1,g1,g1]);
my_axis = axis;
% Afin que le sonag ait une allure lisible, on limite la valeur max
% sur l'axe des ordonnees a ACOU_FECH/2
axis([my_axis(1) my_axis(2) my_axis(3) ACOU_FECH/2]);

titre('SPECTROGRAM');  
% On rcrit le titre de la fenetre
if INDEX == 1
  ylim = get(hsub,'Ylim');
  xlim = get(hsub,'Xlim');
 % titre_fen_princ((xlim(2)-xlim(1))/2, ylim(2)+(ylim(2)-ylim(1))/3, ['Fichier ',ACOU_NOM_FIC,' de type ',ACOU_TYP_FIC]);
end

% On rend actif le menu deroulant
set(hsub,'Buttondownfcn','plot_menu');

% On dsactive les anciens graphes
% et active le courant
active_graphe;

% mise  jour des bornes du curseur
if CURSEUR
    maj_curseur; 
end

% Rglage du spectrogramme
taille_ecran = get(0,'ScreenSize');
hfen = figure('Numbertitle','off','Name','Spectrog.',...
    'Units','pixel', 'MenuBar', 'none', 'Position',[830 taille_ecran(4)-130 200 90]);
uicontrol(hfen,'Style','Frame','Position',[0 0 200 90]);

% Barre de rglage de l'emphase
uicontrol(hfen,'Style','Text','String','Rglage emphase :','Units','Pixel',...
    'Position',[5 70 190 15]);
scroll = uicontrol(hfen,'Style','Slider','Units','pixel','Position',...
    [5 50 190 15],'Min',0,'Max',100,'Value',Esp,...
    'Callback','acou_curs_spec(1)');

% Barre de rglage du niveau de gris
uicontrol(hfen,'Style','Text','String','Rglage niveau de gris :','Units','Pixel',...
    'Position',[5 25 190 15]);
scroll = uicontrol(hfen,'Style','Slider','Units','pixel','Position',...
    [5 5 190 15],'Min',1,'Max',64,'Value',asp,...
    'Callback','acou_curs_spec(0)');

watchoff(figNumber);
if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end
figure(NUM_FEN);
