% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : calc_coord_etiq.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 01.09.99
% Modifi par CS le 14/02/17 :
%       ajout du titre de toutes les fentres (buf_titre)
%
% Contenu : Calcule les coordonnes de l'tiquette 
%           spcifie (curseur, tiquettes min, max
%           ppz, etc.) dans chaque graphe mais 
%           ne les affiche pas.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% function [buf_y, buf_titre] = calc_coord_etiq(pos_sb)
function [buf_y] = calc_coord_etiq(pos_sb)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : calc_coord_etiq(instant)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN NB_LIG NB_COL INDEX

buf_y = [];
buf_titre = [];

if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end
figure(NUM_FEN);

% Recherche le nombre d'axes prsents dans la fenetre
%----------------------------------------------------
tous_axes = findobj(gcf,'Type','axes');

% Pour traiter les axes (les subplots) dans le bon ordre :
%[axes_tries,ind_axes_tries] = sort(tous_axes); 

for ind_axes = 1 : length(tous_axes)
  
  % Recherche de tous les signaux et tiquettes contenus ds l'axe courant
  %----------------------------------------------------------------------

%   gr_lines = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line');
  gr_lines = findobj(tous_axes(ind_axes),'Type','line');

  htext = findobj(tous_axes(ind_axes),'Type','text','Color',[0 1 0]); %titre en vert
  titre_tmp = get(htext,'String');

  if ~isempty(gr_lines)
%     subplot(tous_axes(ind_axes_tries(ind_axes)));
    subplot(tous_axes(ind_axes));
    [gr_lines_tries,ind_gr_lines_tries] = sort(gr_lines); 

    for ind_gr = 1 : length(gr_lines)
       % Rcupre les coord en x en y du graphe
       %---------------------------------------
       val_x = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Xdata');

       % On ne s'intresse qu'aux signaux et on vacue les tiquettes
       if (length(val_x) > 2) 
          val_y = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Ydata');

          % Recherche l'indice dans val_x de la valeur
          % de la position de l'tiquette (ou curseur)
          %--------------------------------------------
          [m,ind] = min(abs(val_x - pos_sb));
          buf_y = [buf_y val_y(ind)];
          val_x = [];
          val_y = [];
          
%           % Pour le titre
%           buf_titre = [buf_titre; titre_tmp];
       end
    end
  
  end
end

% On s'assure que le gca n'a pas chang
subplot(NB_LIG+1,NB_COL,INDEX);


