% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : couper.m
% Source : Matlab
% Date : 15.07.99
% Auteur : H. Loevenbruck
% Modifi le 24/09/2002
% Contenu : Coupe tous les signaux se trouvant 
%           dans la fenetre, entre les instants
%           slectionns  la souris (ces instants compris).
%
% Marche pour les signaux temporels et pour les
% spectrogrammes.
%
% Si les signaux avaient t zooms,
% la coupe a lieu sur les signaux originaux (dzooms)
%
% Lorsqu'un signal ACOUSTIQUE a t coup, c'est 
% le signal coup qui sera utilis pour tous les
% traitements ultrieurs (F0, formants, LPC, etc.)
%
% Attention l'affichage des titres ne marche bien
% que si le titre est en vert.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function couper(debut, fin)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 2
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : couper(instant1, instant2)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global ACOU_TPS_CUT 
global ACOU_FECH 
global ACOU_SIG ACOU_SIG_CUT
global INDEX NUM_FEN
global ACOU_LONG_FEN ACOU_OVER_FEN
global SUPERPOSE
global FLAG_ZOOM

if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end

figure(NUM_FEN);
maj_graphe_courant;

% Sauvegarde de l'index du graphe actif
SAUV_INDEX = INDEX;

% Sauvegarde du mode de superposition courant
SAUV_SUPERPOSE = SUPERPOSE;
SUPERPOSE = 0;

%===================================================
% Avant de couper, on dezoome, si il y a eu un zoom
% sinon l'affichage du spectro ne marchera pas
%===================================================
if FLAG_ZOOM
   zoom_out;
end

%====================================================
% Recherche du nombre d'axes (ou subplots) prsents 
% dans la fenetre.
% Et triage par ordre de disposition  l'cran. 
%====================================================

tous_axes = findobj(gcf,'Type','axes');
[axes_tries,ind_axes_tries] = sort(tous_axes); 

for ind_axes = 1 : length(tous_axes)
     
  axe_contient_image = 0; 
  spec_trace = 0;
  %=======================
  % Cas d'un spectrogramme
  %=======================
  gr_images = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','image');

  if ~isempty(gr_images)
    axe_contient_image = 1;
    subplot(tous_axes(ind_axes_tries(ind_axes)));
    maj_graphe_courant;

    for ind_gr = 1 : length(gr_images)
       % Rcupre les carac de l'image
       %------------------------------
       donnees_temporelles = get(gr_images(ind_gr),'Xdata'); %si formants superposs au spectro, par ex
    end   
    indice_min = round(ACOU_FECH*debut + 1);
    indice_max = round(ACOU_FECH*fin + 1);

    if ~isempty(ACOU_SIG_CUT)
          tmp_acou_sig = ACOU_SIG_CUT';
    else 
          tmp_acou_sig = ACOU_SIG';
    end
       
    if (indice_min >= 1) & (indice_max <= length(tmp_acou_sig)) & (indice_min <= indice_max)
           donnees_apres_coupe = [tmp_acou_sig(1:indice_min-1) tmp_acou_sig(indice_max+1:length(tmp_acou_sig))];
           temps_apres_coupe = 0 : 1/ACOU_FECH : (length(donnees_apres_coupe)-1)/ACOU_FECH; 

           % Le signal coup est un signal acoustique : cas particulier 
           % On sauvegarde les donnes dans variables temporaire et globale
           % et on sauvegarde les valeurs temporelles correspondantes.
           % On ne fera le trac du spectrogram que quand les ventuels
           % graphes superposs  celui-ci auront t rcuprs.
           %---------------------------------------------------------------
           tmp_acou_sig_cut = donnees_apres_coupe';
           tmp_acou_tps_cut = temps_apres_coupe;           
           ACOU_SIG_CUT = donnees_apres_coupe';
           ACOU_TPS_CUT = temps_apres_coupe;
     else
          errordlg(' L''extrait  couper ne se trouve pas dans le signal','Erreur','on');
          return;
     end
    
  end % cas axe contient une image

  %==========================
  % Cas d'un graphique simple
  %==========================

  % Recherche de tous les signaux et tiquettes 
  % contenus ds l'axe courant 
  %--------------------------------------------

  gr_lines = findobj(tous_axes(ind_axes_tries(ind_axes)),'Type','line');

  if ~isempty(gr_lines)
     subplot(tous_axes(ind_axes_tries(ind_axes)));

     % recherche du titre en green
     %----------------------------
     objet_titre = findobj(gca,'Type','text','Color',[0 1 0]);  
     ancien_titre = get(objet_titre, 'string');
     maj_graphe_courant;

     [gr_lines_tries,ind_gr_lines_tries] = sort(gr_lines); 

     % Le raffichage du signal coup supprime les signaux 
     % ventuellement superposs (tiquettes, formants, etc.)
     % Il faut donc sauvegarder les valeurs Xdata et Ydata
     %-------------------------------------------------------
     for ind_gr = 1 : length(gr_lines)

        length_donnees(ind_gr) = length(get(gr_lines(ind_gr_lines_tries(ind_gr)),'Xdata'));
        donnees_tempo(ind_gr, 1:length_donnees(ind_gr)) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Xdata');
        donnees_mes(ind_gr, 1: length_donnees(ind_gr)) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Ydata');
        length_line(ind_gr) = length(get(gr_lines(ind_gr_lines_tries(ind_gr)),'LineStyle'));
        length_marqueur(ind_gr) = length(get(gr_lines(ind_gr_lines_tries(ind_gr)),'Marker'));
        if strcmp(get(gr_lines(ind_gr_lines_tries(ind_gr)),'LineStyle'), 'none')
           trait(ind_gr, 1: length_marqueur(ind_gr) ) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'Marker');
           length_trait(ind_gr) = length_marqueur(ind_gr);
        else 
           trait(ind_gr, 1: length_line(ind_gr) ) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'LineStyle');
           length_trait(ind_gr) = length_line(ind_gr);
        end
        couleur(ind_gr, : ) = get(gr_lines(ind_gr_lines_tries(ind_gr)),'color');
     end

     axe_contient_signal = 0;    
  
     for ind_gr = 1 : length(gr_lines)
       donnees_temporelles = donnees_tempo(ind_gr, 1: length_donnees(ind_gr));
       donnees_mesures = donnees_mes(ind_gr, 1: length_donnees(ind_gr));

       % On ne s'intresse qu'aux signaux et on vacue les tiquettes
       %-------------------------------------------------------------
       if (length(donnees_temporelles) > 2) 

           BorneSupX = donnees_temporelles(length(donnees_temporelles));
           FrequenceEch = (length(donnees_temporelles) -1)/BorneSupX;
           indice_min = round(FrequenceEch*debut + 1);
           indice_max = round(FrequenceEch*fin + 1);

           if (indice_min >= 1) & (indice_max <= length(donnees_mesures)) & (indice_min <= indice_max)
               donnees_apres_coupe = [donnees_mesures(1:indice_min-1) donnees_mesures(indice_max+1:length(donnees_mesures))];
               temps_apres_coupe = 0 : 1/FrequenceEch : (length(donnees_apres_coupe)-1)/FrequenceEch; 

               if (axe_contient_image & ~spec_trace)
                   acou_spectro;
                   spec_trace = 1;
                   SUPERPOSE = 1;
               end

               if (axe_contient_signal)
                  SUPERPOSE = 1;
               end

               trace_graphe(donnees_apres_coupe, temps_apres_coupe, ancien_titre, trait(ind_gr, 1 : length_trait(ind_gr)), couleur(ind_gr, :) );

               % Si le signal coup est un signal acoustique : cas particulier 
               % On sauvegarde les donnes dans une variable temp : tmp_acou_sig
               % et on sauvegarde les valeurs temporelles correspondantes.
               %----------------------------------------------------------------
               if (round(FrequenceEch) == ACOU_FECH)
                  tmp_acou_sig_cut = donnees_apres_coupe';
                  tmp_acou_tps_cut = temps_apres_coupe;
               end
           else
               errordlg(' L''extrait  couper ne se trouve pas dans le signal','Erreur','on');
               return;
           end
           
           axe_contient_signal = 1;
       end
     end %for graphes de l'axe
     SUPERPOSE = 0;
  end % cas axe contient signaux et tiquettes

  %si le spectro n'a toujours pas t trac, il faut le faire.
  if (axe_contient_image & ~spec_trace)
     acou_spectro;
     spec_trace = 1;
  end
 
  clear length_donnees
  clear donnees_tempo
  clear donnees_mes
  clear length_trait
  clear trait
  clear couleur

end

%=====================================
% On stocke le signal acoustique coup
%===================================== 
ACOU_SIG_CUT = tmp_acou_sig_cut;
ACOU_TPS_CUT = tmp_acou_tps_cut;

%==========================================
% On s'assure que le graphe activ est bien 
% celui qui l'tait avant la coupe
%==========================================
INDEX = SAUV_INDEX;
maj_graphe_courant;
active_graphe;

%======================================
% Restauration du mode de superposition
%======================================
SUPERPOSE = SAUV_SUPERPOSE;

%============================
% Rafraichissement du curseur
%============================
pos_curs; 

