% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : ema_vit_tang.m
% Source : Matlab
% Auteur : C. Savariaux
% Date : 21.06.99
% Modifi par H. Loevenbruck 24.09.99
% Modifi par CS le 10/12/03 : on utilise filtre_cheby pour le filtrage
% Dernire modification : CS, le 16/01/07
%   passage en 3D
% Contenu : Calcule puis trace la vitesse tangentielle d'une
%          bobine dans la fenetre principale
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%function ema_vit_tang(sig_X, sig_Y, nom)
function ema_vit_tang(sig_X, sig_Y, sig_Z, nom)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 4
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : ema_vit_tang(sig_X, sig_Y, sig_Z, nom)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN EMA_TPS EMA_FECH EMA_FLAG CHEBY_FREQ_COUP

% Teste si le calcul des trajectoires a dj t effectu
if EMA_FLAG == 0
  errordlg(' Lancer la commande ''Trajectoire'' avant de visualiser les vitesses.',...
      'Erreur','on');
else

  % Si aucune fenetre n'a t ouverte, on ouvre celle par defaut
  if NUM_FEN == 0
    fenetre(1,4,[20 90],[450 650],'Fenetre Principale');
  end 

  % Calcul de la vitesse
  temp_vit_X = calc_vit(sig_X,EMA_FECH);
  temp_vit_Y = calc_vit(sig_Y,EMA_FECH);
  
  % teste si 3D
  if ~isempty(sig_Z)
      temp_vit_Z = calc_vit(sig_Z,EMA_FECH);
      temp_vit_tang = sqrt((temp_vit_X.*temp_vit_X)+(temp_vit_Y.*temp_vit_Y)+(temp_vit_Z.*temp_vit_Z));
  else
      temp_vit_tang = sqrt((temp_vit_X.*temp_vit_X)+(temp_vit_Y.*temp_vit_Y));
  end
  
  [vit_tang] = filtre_cheby(temp_vit_tang, EMA_FECH, CHEBY_FREQ_COUP);
  
  %[C D] = cheby1(CHEBY_ORD_FILT,0.5, (2*CHEBY_FREQ_COUP)/EMA_FECH);
  %vit_tang = filtfilt (C,D,temp_vit_tang);

  % Affichage
  trace_graphe(vit_tang,EMA_TPS,['VIT. TANG. ',nom], '-', [ 1 1 0]);
end
