% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : enr_etiq.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 15.10.99
% Contenu : Enregistre les tiquettes dans un
%           fichier.
%           NIV_ETIQ niveaux d'tiquette sont possibles.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function enr_etiq(nomfic)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : enr_etiq(nomfic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NUM_FEN ACOU_NOM_FIC ACOU_TYP_FIC COULEUR_ETIQ NIV_ETIQ
posx = [];

if isempty(ACOU_NOM_FIC)
    ACOU_NOM_FIC = nomfic;
end

if isempty(ACOU_TYP_FIC)
    ACOU_TYP_FIC = 'inconnu';
end

% Ouverture du fichier en criture
%=================================
fid = fopen(nomfic,'a');

if fid == -1 
  errordlg(' Impossible de crer un fichier d''tiquettes ! ','Erreur','on');
  return;
end

% Ecriture du nom et du type de fichier
%======================================
fprintf(fid,'TRAP : Fichier d''etiquettes\n');
fprintf(fid,'signal : %s \n',ACOU_NOM_FIC);
fprintf(fid,'type : %s\n',ACOU_TYP_FIC);
fprintf(fid,'comment : cree le %s\n', date);
fprintf(fid, 'color : %1.2f %1.2f %1.2f\n', COULEUR_ETIQ(1,1), COULEUR_ETIQ(1,2), COULEUR_ETIQ(1,3));
fprintf(fid, 'nfields : %i\n\n', NIV_ETIQ);

% Cherche les tiquettes dans la fenetre courante 
%================================================
if NUM_FEN == 0
  errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
  return;
end
figure(NUM_FEN);

for niveau = 1 : NIV_ETIQ

  % Cherche les textes des etiquettes
  %----------------------------------
  etiq = findobj(gcf,'Type','text','Color',COULEUR_ETIQ(niveau,:));

  for i = 1 : length(etiq)

    % Cherche les valeurs sur les axes des x (le temps)
    %--------------------------------------------------
    pos = get(etiq(i),'Position');
    posx = [posx, pos(1)];

    % Cherche les valeurs sur les axes des y, 
    %----------------------------------------
    [buf_y] = calc_coord_etiq(pos(1));
    if ~isempty(buf_y)
       posy(i,:) = buf_y;
    end
  end

  [y,sort_ind] = sort(posx); % trie les valeurs temporelles

  for i = sort_ind  % pour tous les indices tris
    nom = get(etiq(i),'String');

    % Affiche la valeur sur l'axe des x (le temps), le niveau d'tiquette, le nom
    fprintf(fid,'%f\t%i\t%s',posx(i),niveau,nom);

    % Affiche les valeurs sur l'axe des y ( part les formants)
    for j = 1:size(posy,2)
       fprintf(fid,'\t%f',posy(i,j) );
    end
    fprintf(fid,'\n');
  end

  etiq = [];
  posx = [];
  posy = [];
end

msg = ['Fichier d''tiquettes cr : ' nomfic];
disp(msg);

fclose(fid);



