% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : fenetre.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Dernire modification par H. Loevenbruck 12.09.02
% Contenu : Cration de la fenetre principale
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function fenetre(col, lig, coord, dim, titre)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 5
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : fenetre(col, lig, coord, dim, titre)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global NB_LIG NB_COL NUM_FEN INDEX ACOU_NOM_FIC ...
    MES_NOM_FIC ACOU_NOM_AFFIC ACOU_NOM_TEMP COULEUR_FOND CURSEUR 

taille_ecran = get(0,'ScreenSize');
hfen = figure('Numbertitle','off','Name',titre,...
    'Units','pixel','MenuBar', 'none', 'Color', COULEUR_FOND,...
    'Position', [coord(1) taille_ecran(4)-coord(2)-dim(2) dim(1) dim(2)]);

if COULEUR_FOND == [1 1 1]
    colordef(hfen,'white');
end

% Affectation des variables globales
%-----------------------------------
NB_LIG = lig;
NB_COL = col;
NUM_FEN = hfen;
INDEX = 1; %Le premier se fera ds le premier subplot.

% Affichage des diagrammes avec le nombre 
% de lignes et de colonnes specifi
%----------------------------------------
% Rservation de place pour lig lignes et col colonnes
% Plus une ligne pour etiq et curseur

for i=1 : (lig*col)
  dessin(i) = subplot(lig+1,col,i);
  %set(dessin(i),'color',COULEUR_FOND); % Fond grisatre
  set(dessin(i),'Buttondownfcn','plot_menu'); % Menu de chgt d'chelle,etc.
end

% Lorsque l'on clique ds le fond de la fenetre :
% Effacement du menu droulant si aucun bouton slectionn
% et prise en compte de la fenetre slectionne si plusieurs fenetres
%---------------------------------------------------------------------
set(hfen,'Buttondownfcn','select_fen');

% Affichage du curseur
%---------------------
% On rend invisible la ligne rserv pour les tiquettes et le curseur
for i = lig*col+1 : (lig+1)*col
  subplot(lig+1,col,i)  
  set(gca,'visible','off')
end

% le curseur sera dans le subplot invisible le plus a gauche (le premier)
subplot(lig+1,col,lig*col+1)
taille_fen = get(gcf,'Position');
pos_axe = get(gca,'Position'); % dernier axe avant les tiquettes
xlim = get(subplot(lig+1,col,1),'Xlim');

x_scroll = pos_axe(1) -20/taille_fen(3);
y_scroll = 35/taille_fen(4);
width_scroll =  pos_axe(3) +40/taille_fen(3);
heigth_scroll = 15/taille_fen(4);

if CURSEUR
    scroll = uicontrol(hfen,'Style','Slider','Units','normalized','Position',...
        [x_scroll y_scroll width_scroll heigth_scroll],'Value',0.1, ...
         'Callback','pos_curs');
%     scroll = uicontrol(hfen,'Style','Slider','Position',...
%         [x_scroll y_scroll width_scroll heigth_scroll],'Value',1, ...
%          'Callback','pos_curs');
end

% Titre de la fenetre
%---------------------
xlim = get(dessin(1),'Xlim');
ylim = get(dessin(1),'Ylim');
if ~isempty(ACOU_NOM_FIC)
   long=length(ACOU_NOM_FIC);
   long_nouv=0;
   long_nouv_final=0;
   
   
   % Reglage de l'affichage du caractere '_'
   for i=long:-1:1
      ACOU_NOM_TEMP(i)=ACOU_NOM_FIC(i);
      if ACOU_NOM_TEMP(i)=='_'
         ACOU_NOM_TEMP(i)='-'; 
      end
      if (ACOU_NOM_TEMP(i)~='\')
         long_nouv=long_nouv+1;
      else
         if long_nouv_final==0;
            long_nouv_final=long_nouv;
         end  
      end
    end
    
   for i=1:long_nouv_final
      ACOU_NOM_AFFIC(i)=ACOU_NOM_TEMP(long-long_nouv_final+i);
   end
   %titre_fen_princ((xlim(2)-xlim(1))/2, ylim(2)+(ylim(2)-ylim(1))/3, ...
    %   ['Fichier ',ACOU_NOM_AFFIC,' de type ',ACOU_TYP_FIC]);
    
   titre_fen_princ((xlim(2)-xlim(1))/2, ylim(2)+(ylim(2)-ylim(1))/3, ...
       ['Fichier ',ACOU_NOM_AFFIC]);
   
elseif ~isempty(MES_NOM_FIC)
     titre_fen_princ(xlim(1), (ylim(2)-ylim(1))/3, ['Fichier ',MES_NOM_FIC]);
end

%text((xlim(2)-xlim(1))/2,ylim(2)+(ylim(2)-ylim(1))/3,...
%    ['Fichier ',ACOU_NOM_FIC,' de type ',ACOU_TYP_FIC],...
%  'Color','w','HorizontalAlignment','center','FontSize',14);

% 10 Boutons d'dition au bas de la fenetre
%----------------------------------------
uicontrol(hfen,'Style','Pushbutton','String','Couper',...
    'Units', 'Normalized', ...
    'Position',[0 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','couper_dlg');

uicontrol(hfen,'Style','Pushbutton','String','Ecouter',...
    'Units', 'Normalized', ...
    'Position',[taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','acou_lance_ecout');

uicontrol(hfen,'Style','Pushbutton','String','Copier',...
    'Units', 'Normalized', ...
    'Position',[2*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','');

uicontrol(hfen,'Style','Pushbutton','String','Coller',...
    'Units', 'Normalized', ...
    'Position',[3*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','');

uicontrol(hfen,'Style','Pushbutton','String','(d)Zoomer',...
    'Units', 'Normalized', ...
    'Position',[4*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','acou_lance_zoomer');

uicontrol(hfen,'Style','Pushbutton','String','Marquer',...
    'Units', 'Normalized', ...
    'Position',[5*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','marq_dlg(''Etiquette'')');

% uicontrol(hfen,'Style','Pushbutton','String','Eff. tiq.',...
%     'Units', 'Normalized', ...
%     'Position',[6*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
%     'Callback','posc = ginputc(1,''Color'', COULEUR_POINTEUR);eff_etiq(posc(1))');
uicontrol(hfen,'Style','Pushbutton','String','Eff. tiq.',...
    'Units', 'Normalized', ...
    'Position',[6*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','posc = ginput(1);eff_etiq(posc(1))');

uicontrol(hfen,'Style','Pushbutton','String','TitreFen',...
    'Units', 'Normalized', ...
    'Position',[7*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','titre_fenp_dlg');
 
% uicontrol(hfen,'Style','Pushbutton','String','Eff. rep.',...
%     'Units', 'Normalized', ...
%     'Position',[8*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
%     'Callback','posc = ginputc(1,''Color'', COULEUR_POINTEUR);eff_minmaxppz(posc(1))' );
uicontrol(hfen,'Style','Pushbutton','String','Eff. rep.',...
    'Units', 'Normalized', ...
    'Position',[8*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'Callback','posc = ginput(1);eff_minmaxppz(posc(1))' );

uicontrol(hfen,'Style','checkbox','String','Superposer',...
    'Units', 'Normalized', ...
    'Position',[9*taille_fen(3)/(10*taille_fen(3)) 0 taille_fen(3)/(10*taille_fen(3)) 20/taille_fen(4)],...
    'enable', 'on','Callback','maj_superpose' );
 




