% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : init_menu.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Dernire modification 18.03.03
% par H. Loevenbruck et C. Savariaux 
% suppression du menu avec angle de rotation pour EMA
% Contenu : Dfinition du menu
%
% Modifi par CS le 05/07/06 :
%    ajout des menus EGG
% Modifi par CS le 15/02/18 :
%       ajout du mode reperage du tps  20% du max rep_20pc_max, uniquement
%       sur signaux EMA
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function init_menu

% global ACOU_CALC_CEPS EPG_PAL_SIMPLE 

taille_ecran = get(0,'ScreenSize');

% Dfinition de la fenetre de commande principale
%================================================
parent = figure('Numbertitle','off','Name','TRAP - Traitement des signaux de parole',...
    'Units','pixel','MenuBar', 'none', 'Position',[20 taille_ecran(4)-110 901 50]);

uicontrol(parent,'Style','Frame','Backgroundcolor',[0.8 0.8 0.8],...
    'Position',[0 0 901 50]);

% Dfinition du menu Fichier et de ses sous-menus
%================================================
file_menu = uimenu(parent,'Label','Fichier','Separator','on');

ouvrir_menu = uimenu(file_menu, 'Label','Ouvrir','Separator','on');
uimenu(ouvrir_menu, 'Label', 'Fichier acoustique et/ou EPG (binaire)', 'Separator','on',...
    'Callback','acou_ouv_dlg(''Ouvrir fichier acoustique'')');
uimenu(ouvrir_menu, 'Label', 'Fichier EMA (.mat)', 'Separator','on',...
    'Callback','ema_ouv_dlg(''Ouvrir fichier EMA'')');
uimenu(ouvrir_menu, 'Label', 'Fichier TACLE (.tac)', 'Separator','on',...
    'Callback','mes_tac_ouv_dlg(''Ouvrir fichier TACLE'')');
uimenu(ouvrir_menu, 'Label', 'Fichiers EVA', 'Separator','on',...
    'Callback','eva_ouv_dlg(''Ouvrir fichier EVA'')');
uimenu(ouvrir_menu, 'Label', 'Fichier mesures (ASCII)', 'Separator','on',...
    'Callback', 'mes_ouv_dlg(''Ouvrir fichier mesures ASC'')');
uimenu(ouvrir_menu, 'Label', 'Fichier EGG (.DCF)', 'Separator','on',...
    'Callback', 'egg_ouv_dlg(''Ouvrir fichier EGG'')');

uimenu(file_menu,'Label','Charger tiquettes','Separator','on',...
    'Callback','option(''Charger tiquettes'',''Nom du fichier tiquettes :'')');

enreg_menu = uimenu(file_menu,'Label','Enregistrer','Separator','on');
uimenu(enreg_menu,'Label','Etiquettes','Separator','on','Callback',...
    'option(''Enregistrer tiquettes'',''Nom du fichier tiquettes :'')');
uimenu(enreg_menu,'Label','Min - Max - PPZ - Moy','Separator','on','Callback',...
    'option(''Enregistrer Min - Max - PPZ - Moy'',''Nom du fichier de repres min-max-ppz-moy :'')');
uimenu(enreg_menu,'Label','Signal temporel','Separator','on','Callback',...
    'enr_tempo_dlg(''Enregistrer signal temporel'')');
uimenu(enreg_menu,'Label','Formants F1..F5','Separator','on','Callback',...
    'enr_formant_dlg(''Enregistrer Formants F1..F5'')');

%uimenu(enreg_menu,'Label','Signal EMA','Separator','on','Callback',...
%    'option(''Enregistrer EMA'',''Nom du fichier EMA :'')');
%uimenu(enreg_menu,'Label','Signal EPG','Separator','on','Callback',...
%    'option(''Enregistrer EPG'',''Nom du fichier EPG :'')');

uimenu(file_menu,'Label','Quitter','Separator','on',...
    'Callback','quitter');


% Dfinition du menu Options et de ses sous-menus
%================================================
opt_menu = uimenu(parent,'Label','Options','Separator','on');
acou_menu = uimenu(opt_menu,'Label','Acoustique','Separator','on');
ema_menu = uimenu(opt_menu,'Label','EMA','Separator','on');
epg_menu = uimenu(opt_menu,'Label','EPG','Separator','on');
gene_menu = uimenu(opt_menu,'Label','TACLE/Mesures','Separator','on');
flt_menu = uimenu(opt_menu,'Label','Filtrage PBas (Chebyshev)','Separator','on','Callback','filtre_dlg');

% Dfinition des sous-menus de acoustique
%========================================
uimenu(acou_menu,'Label','Frquence d''chantillonnage','Separator','on',...
    'Callback','option(''Acoustique'',''Frquence chantillonnage :'')');

% Dfinition des sous-menus de EMA
%=================================
uimenu(ema_menu,'Label','Frquence d''chantillonnage','Separator','on',...
    'Callback','option(''EMA'',''Frquence chantillonnage :'')');
uimenu(ema_menu,'Label','Nom des bobines','Separator','on',...
    'Callback','ema_nom_bob_dlg');
uimenu(ema_menu,'Label','Unit de visualisation','Separator','on',...
    'Callback','ema_unit_dlg');

% Dfinition des sous-menus de EPG
%=================================
uimenu(epg_menu,'Label','Frquence d''chantillonnage','Separator','on',...
    'Callback','option(''EPG'',''Frquence chantillonnage :'')');
uimenu(epg_menu,'Label','Nom locuteur','Separator','on',...
    'Callback','option(''EPG'',''Nom du locuteur :'')');

% Dfinition des sous-menus de gene
%==================================
uimenu(gene_menu,'Label','Frquence d''chantillonnage','Separator','on',...
    'Callback','option(''Params/Mesures'',''Frquence chantillonnage :'')');
uimenu(gene_menu,'Label','Nombre de Params/Mesures','Separator','on',...
    'Callback','option(''Params/Mesures'',''Nombre total de Params/Mesures :'')');
uimenu(gene_menu,'Label','Nom des Params/Mesures','Separator','on',...
    'Callback','mes_nom_dlg');

% Dfinition du menu Traitement Acoustique et de ses sous-menus
%==============================================================
tacou_menu = uimenu(parent,'Label','Traitement Acoustique','Separator','on');
fzero_menu = uimenu(tacou_menu,'Label','Dtection F0',...
    'Separator','on','Accelerator','d');
uimenu(fzero_menu,'Label','A partir du fichier','Separator','on',...
    'Callback','acou_f0_frm_dlg(''Fichier F0'')');
uimenu(fzero_menu,'Label','Calcul de la F0','Separator','on',...
    'Callback','acou_detect_f0');
uimenu(tacou_menu,'Label','Intensit','Separator','on','Callback','acou_intensite');

filtre_menu = uimenu(tacou_menu,'Label','Filtrage','Separator','on');
uimenu(filtre_menu,'Label','Passe-haut','Separator','on',...
    'Callback','acou_filtre_dlg(''Filtre passe-haut'');');
uimenu(filtre_menu,'Label','Passe-bas','Separator','on',...
    'Callback','acou_filtre_dlg(''Filtre passe-bas'');');
uimenu(filtre_menu,'Label','Passe-haut Remez','Separator','on',...
    'Callback','acou_filtre_dlg(''Filtre Remez'');');
uimenu(tacou_menu,'Label','FFT - LPC','Separator','on',...
    'Callback','acou_fft_dlg(''FFT - LPC'')');
uimenu(tacou_menu,'Label','Cepstre','Separator','on',...
    'Callback','acou_ceps_dlg;ACOU_CALC_CEPS = 1;');

form_menu = uimenu(tacou_menu,'Label','Formants','Separator','on');
uimenu(form_menu,'Label','A partir du fichier','Separator','on',...
    'Callback','acou_f0_frm_dlg(''Fichier Formants'')');
uimenu(form_menu,'Label','Dtection des formants','Separator','on',...
    'Callback','acou_detect_form');

uimenu(tacou_menu,'Label','Spectrogramme','Separator','on',...
    'Callback','acou_spectro');
uimenu(tacou_menu,'Label','Afficher Signal','Separator','on',...
    'Callback','acou_signal');
ecoute_menu = uimenu(tacou_menu,'Label','Ecouter','Separator','on');
uimenu(ecoute_menu,'Label','Signal Original','Separator','on','Callback','acou_ecout_tout');
uimenu(ecoute_menu,'Label','Contenu Fenetre','Separator','on','Callback','acou_ecout_fen');
uimenu(ecoute_menu,'Label','Extrait','Separator','on','Callback','acou_select_ext');

% Dfinition du menu Traitement EMA et de ses sous-menus
%=======================================================
tema_menu = uimenu(parent,'Label','Traitement EMA','Separator','on');
uimenu(tema_menu,'Label','Trajectoire','Separator','on',...
    'Callback','if (ema_traitement) ema_traj_dlg; end');
uimenu(tema_menu,'Label','Vitesse','Separator','on',...
    'Callback','ema_vit_dlg');
uimenu(tema_menu,'Label','Vitesse Tangentielle','Separator','on',...
    'Callback','ema_vit_tan_dlg');
uimenu(tema_menu,'Label','Acclration','Separator','on',...
    'Callback','ema_acc_dlg');
uimenu(tema_menu,'Label','Coupe Sagittale','Separator','on',...
    'Callback','ema_choix_palais;');
uimenu(tema_menu,'Label','Animation','Separator','on','Callback','ema_get_coord_anim');

rep_menu = uimenu(tema_menu,'Label','Reprage','Separator','on');
uimenu(rep_menu,'Label','Minima locaux','Separator','on','Callback','minmaxppz(1,''EMA'', ''manuel'');');
uimenu(rep_menu,'Label','Minimum absolu','Separator','on','Callback','minmaxppz(6,''EMA'', ''auto'');');
uimenu(rep_menu,'Label','Maxima locaux','Separator','on','Callback','minmaxppz(2,''EMA'', ''manuel'');');
uimenu(rep_menu,'Label','Maximum absolu','Separator','on','Callback','minmaxppz(7,''EMA'', ''auto'');');
uimenu(rep_menu,'Label','90%-10% de chute','Separator','on','Callback','minmaxppz(5,''EMA'', ''manuel'');');
uimenu(rep_menu,'Label','20% du max','Separator','on','Callback','minmaxppz(8,''EMA'', ''manuel'');');
uimenu(rep_menu,'Label','Passages par Zro','Separator','on','Callback','minmaxppz(3,''EMA'', ''manuel'');');
uimenu(rep_menu,'Label','Moyenne','Separator','on','Callback','minmaxppz(4,''EMA'', ''manuel'');');

uimenu(tema_menu,'Label','Facteurs Tilt','Separator','on',...
    'Callback','ema_calc_tilt');

% Dfinition du menu Traitement EPG et de ses sous-menus
%=======================================================
tepg_menu = uimenu(parent,'Label','Traitement EPG','Separator','on');
uimenu(tepg_menu,'Label','Slection des rgions','Separator','on','Callback','epg_reg_dlg');
uimenu(tepg_menu,'Label','Sauvegarder rgions','Separator','on','Callback','epg_sauve_reg');
uimenu(tepg_menu,'Label','Taux de constriction','Separator','on','Callback',...
    'option(''Taux de constriction'',''Numro de la rgion :'')');

traj_epg_menu = uimenu(tepg_menu,'Label','Trajectoire EPG','Separator','on');
uimenu(traj_epg_menu,'Label','Charger fichier','Separator','on','Callback',...
    'epg_traj_dlg');
uimenu(traj_epg_menu,'Label','Trajectoires EPG charges','Separator','on','Callback',...
    'epg_choix_traj_dlg(''Trajectoire'')');
uimenu(tepg_menu,'Label','Vitesse','Separator','on','Callback',...
    'epg_choix_traj_dlg(''Vitesse'')');
uimenu(tepg_menu,'Label','Acclration','Separator','on','Callback',...
    'epg_choix_traj_dlg(''Acclration'')');

pal_menu = uimenu(tepg_menu,'Label','Palais','Separator','on');
uimenu(pal_menu,'Label','Simple','Separator','on','Callback','EPG_PAL_SIMPLE=1;');
uimenu(pal_menu,'Label','Srie','Separator','on','Callback',...
    'option(''Palais srie'',''Nombre de palais (av. et ap. inst. courant) :'')');
repg_menu = uimenu(tepg_menu,'Label','Reprage','Separator','on');
uimenu(repg_menu,'Label','Minima locaux','Separator','on','Callback','minmaxppz(1,''EPG'', ''manuel'')');
uimenu(repg_menu,'Label','Minimum absolu','Separator','on','Callback','minmaxppz(6,''EPG'', ''auto'');');
uimenu(repg_menu,'Label','Maxima locaux','Separator','on','Callback','minmaxppz(2,''EPG'', ''manuel'')');
uimenu(repg_menu,'Label','Maximum absolu','Separator','on','Callback','minmaxppz(7,''EPG'', ''auto'');');
uimenu(repg_menu,'Label','90%-10% de chute','Separator','on','Callback','minmaxppz(5,''EPG'', ''manuel'');');
uimenu(repg_menu,'Label','Passages par Zro','Separator','on','Callback','minmaxppz(3,''EPG'', ''manuel'');');
uimenu(repg_menu,'Label','Moyenne','Separator','on','Callback','minmaxppz(4,''EPG'', ''manuel'');');

% Dfinition du menu Traitement Mesure et de ses sous-menus
%===========================================================
tgene_menu = uimenu(parent,'Label','Traitement TACLE/Mesure','Separator','on');
uimenu(tgene_menu,'Label','Trajectoire','Separator','on','Callback',...
    'mes_choix_traj_dlg(''Trajectoire'')');
uimenu(tgene_menu,'Label','Vitesse','Separator','on','Callback',...
    'mes_choix_traj_dlg(''Vitesse'')');
uimenu(tgene_menu,'Label','Acclration','Separator','on','Callback',...
    'mes_choix_traj_dlg(''Acclration'')');
uimenu(tgene_menu,'Label','Filtrage','Separator','on','Callback',...
    'mes_choix_traj_dlg(''Filtrage'')');
rgene_menu = uimenu(tgene_menu,'Label','Reprage','Separator','on');
uimenu(rgene_menu,'Label','Minima locaux','Separator','on','Callback','minmaxppz(1,''MES'', ''manuel'')');
uimenu(rgene_menu,'Label','Minimum absolu','Separator','on','Callback','minmaxppz(6,''MES'', ''manuel'')');
uimenu(rgene_menu,'Label','Maxima locaux','Separator','on','Callback','minmaxppz(2,''MES'', ''manuel'')');
uimenu(rgene_menu,'Label','Maximum absolu','Separator','on','Callback','minmaxppz(7,''MES'', ''manuel'')');
uimenu(rgene_menu,'Label','90%-10% de chute','Separator','on','Callback','minmaxppz(5,''MES'', ''manuel'');');
uimenu(rgene_menu,'Label','Passages par Zro','Separator','on','Callback','minmaxppz(3,''MES'', ''manuel'');');
uimenu(rgene_menu,'Label','Moyenne','Separator','on','Callback','minmaxppz(4,''MES'', ''manuel'');');

% Dfinition du menu Traitement EVA
%===========================================================
teva_menu = uimenu(parent,'Label','Traitement EVA','Separator','on');
uimenu(teva_menu,'Label','Trajectoire','Separator','on','Callback',...
    'eva_traj_dlg');
uimenu(teva_menu,'Label','Vitesse','Separator','on','Callback',...
    'eva_vit_dlg');
uimenu(teva_menu,'Label','Acclration','Separator','on','Callback',...
    'eva_acc_dlg');
uimenu(teva_menu,'Label','Filtrage','Separator','on','Callback',...
    'eva_flt_dlg');
reva_menu = uimenu(teva_menu,'Label','Reprage','Separator','on');
uimenu(reva_menu,'Label','Minima locaux','Separator','on','Callback','minmaxppz(1,''EVA'', ''manuel'')');
uimenu(reva_menu,'Label','Minimum absolu','Separator','on','Callback','minmaxppz(6,''EVA'', ''auto'')');
uimenu(reva_menu,'Label','Maxima locaux','Separator','on','Callback','minmaxppz(2,''EVA'', ''manuel'')');
uimenu(reva_menu,'Label','Maximum absolu','Separator','on','Callback','minmaxppz(7,''EVA'', ''auto'')');
uimenu(reva_menu,'Label','90%-10% de chute','Separator','on','Callback','minmaxppz(5,''EVA'', ''manuel'');');
uimenu(reva_menu,'Label','Passages par Zro','Separator','on','Callback','minmaxppz(3,''EVA'', ''manuel'');');
uimenu(reva_menu,'Label','Moyenne','Separator','on','Callback','minmaxppz(4,''EVA'', ''manuel'');');

% Dfinition du menu Traitement EGG
%===========================================================
tegg_menu = uimenu(parent,'Label','Traitement EGG','Separator','on');
uimenu(tegg_menu,'Label','Trajectoire','Separator','on','Callback',...
    'egg_traj_dlg');
uimenu(tegg_menu,'Label','Vitesse','Separator','on','Callback',...
    'egg_vit_dlg');
uimenu(tegg_menu,'Label','Acclration','Separator','on','Callback',...
    'egg_acc_dlg');
uimenu(tegg_menu,'Label','Filtrage','Separator','on','Callback',...
    'egg_flt_dlg');
regg_menu = uimenu(tegg_menu,'Label','Reprage','Separator','on');
uimenu(regg_menu,'Label','Minima locaux','Separator','on','Callback','minmaxppz(1,''EGG'', ''manuel'')');
uimenu(regg_menu,'Label','Minimum absolu','Separator','on','Callback','minmaxppz(6,''EGG'', ''auto'')');
uimenu(regg_menu,'Label','Maxima locaux','Separator','on','Callback','minmaxppz(2,''EGG'', ''manuel'')');
uimenu(regg_menu,'Label','Maximum absolu','Separator','on','Callback','minmaxppz(7,''EGG'', ''auto'')');
uimenu(regg_menu,'Label','90%-10% de chute','Separator','on','Callback','minmaxppz(5,''EGG'', ''manuel'');');
uimenu(regg_menu,'Label','Passages par Zro','Separator','on','Callback','minmaxppz(3,''EGG'', ''manuel'');');
uimenu(regg_menu,'Label','Moyenne','Separator','on','Callback','minmaxppz(4,''EGG'', ''manuel'');');

% Dfinition du menu Fenetre et de ses sous-menus
%================================================
fen_menu = uimenu(parent,'Label','Fenetres','Separator','on');
princ_menu = uimenu(fen_menu,'Label','Principale','Separator','on');
sync_menu = uimenu(fen_menu,'Label','Synchrone','Separator','on');

% Dfinition des sous-menus de Principale
%================================================
uimenu(princ_menu,'Label','Dfaut','Separator','on',...
    'Callback','fenetre(1,4,[20 90],[450 650],''Fenetre Principale'')');
uimenu(princ_menu,'Label','Configurer','Separator','on',...
    'Callback','config_fen_princ');

% Dfinition des sous-menus de Synchrone
%================================================
uimenu(sync_menu,'Label','Dfaut','Separator','on',...
    'Callback','synchrone(1,[500 90],[500 270],''Fenetre Synchrone'')');
uimenu(sync_menu,'Label','Configurer','Separator','on',...
    'Callback','config_fen_sync');
