% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : mes_ouv.m
% Source : Matlab
% Auteur : H. Loevenbruck
% Date : 06.07.99
% Dernire Modification C. Savariaux : 18.09.02
% Contenu : Lecture d'un fichier de mesures (ASCII)
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function mes_ouv(nom_fic)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 1
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : mes_ouv(nom_fic)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global MES_FECH MES_NB MES_TPS MES_DATA MES_NOM_FIC

if MES_FECH == 0
  errordlg(' Veuillez spcifier la frquence d''chantillonnage !','Erreur','on');
  return;
end

if MES_NB == 0
  errordlg(' Veuillez d''abord spcifier le nombre de mesures !','Erreur','on');
  return;
end


if isempty(nom_fic)
  errordlg(' Veuillez donner un nom de fichier de mesures !','Erreur','on');
  return;
end

MES_NOM_FIC = nom_fic;

fid = fopen(nom_fic,'r');
if fid == -1   
  errordlg([' Fichier ',nom_fic,' introuvable'],'Rsultat','on');
  return;
else

  MES_DATA = [];
  MES_TPS = [];

  % Lecture du premier caractre (pour les fichiers avec en-tete)
  %=============================
  if fscanf(fid,'%c',1) == '#'
      line_temp = fgetl(fid);
  else
      frewind(fid);
  end
  
  % Lecture des donnes
  %====================
  data = fscanf(fid, '%f', [MES_NB inf]);
  nb_ech = size(data,2) ;

  fscanf(fid,'%c',1)
  
  if ~feof(fid)
     errordlg(' Le nombre de mesures est erron !', 'Erreur', 'on');
     return;
  end

  for i = 1 :  MES_NB
     MES_DATA(i,1:nb_ech) = reshape(data(i,:),1,nb_ech);
  end

  % Calcul des donnes temporelles
  %===============================
  MES_TPS = 0 : 1/MES_FECH : (nb_ech-1)/MES_FECH;

  % Fermeture du fichier
  %======================
  fclose(fid);
end
