function mes_tac2asc(nom_fich_tac,param)

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function tac2asc : met au format ASCII en colonne les valeurs des
%  parametres contenu dans param pour lecture sous PRAAT ou TRAP
%  Sauvegrade dans un fichier .lev
%
%  Remarque : les parametres de sortie sont toujours stocks dans l'ordre 
%             A B S P1 P2 C
%  Si un ordre diffrent est spcifi en entre, un message d'info
%  rappellera l'ordre effectif en sortie.
%  
%  Exemple d'utilisation :
%  mes_tac2asc('d:\temp\ruhi2.tac',['A' 'P1' 'S']);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%														
%	date : 13/09/02
%	auteur : Christophe Savariaux								
% 	ICP - Grenoble		
%	Modifs : H. Loevenbruck 24/09/02												
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% On ouvre le fichier .tac et on rcupre les donnes
%=====================================================
fin=fopen(nom_fich_tac,'r');

if (fin == -1)
   msg = sprintf('Impossible d''ouvrir le fichier de paramtres %s', nom_fich_tac);
   errordlg(msg, 'Erreur','on');
   return;
end

% On saute les 7 premieres lignes
for i=1:7
   fgetl(fin);
end

%on initialise les variables
NbLignes = 0;

while 1
   NbLignes = NbLignes + 1;
   TC_tmp(:,NbLignes) = fscanf(fin, '%c', 11); % on recupere le time-code
   Trame_tmp(:,NbLignes) = fscanf(fin, '%c', 2); % on recupere la trame
   if (Trame_tmp(2,NbLignes) == 'A') % rcupre la trame 0 si A, 1 si B
      Trame = 0;
   else
      Trame = 1;
   end
   TC(NbLignes,:)= [str2num(TC_tmp(2,NbLignes)) 10*str2num(TC_tmp(4,NbLignes))+str2num(TC_tmp(5,NbLignes)) 10*str2num(TC_tmp(7,NbLignes))+str2num(TC_tmp(8,NbLignes)) ...
         10*str2num(TC_tmp(10,NbLignes))+str2num(TC_tmp(11,NbLignes)) Trame];
   Val(:,NbLignes) = fscanf(fin, '%f', 36); % on recupere les valeurs
   saut = fscanf(fin, '%c', 2); % on saute les caracteres de fin de ligne
   
   % on teste si on est a la fin du fichier
   fscanf(fin, '%c', 1);
   if (feof(fin) == 1) % on sort
      break;
   else      % sinon on recule d'un element
      fseek(fin,-1,0);
   end   
end

fclose(fin);

% Cration et ouverture du fichier de sortie
nomfich_out = [nom_fich_tac(1:length(nom_fich_tac)-4), '.lev'];

fid_f = fopen(nomfich_out,'w');
if (fid_f == -1)
    errordlg('Erreur d''ouverture du fichier report !!','Erreur','on');
    return;
end

sortie = [];
ind = 0;
indice_lecture = 0;
chgt_ordre = 0;
fprintf(fid_f, '%s', '#');

% On cherche ce qui est demand
indice_trouve = strfind('A',param);
if ~isempty(indice_trouve)
    ind = ind+1;
    indice_lecture = indice_lecture+1;
    sortie(ind,:) = Val(1,:);
    fprintf(fid_f, '%s\t', 'A');
    if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
    end
end

indice_trouve = strfind('B',param);
if ~isempty(indice_trouve)
   ind = ind+1;
   indice_lecture = indice_lecture+1;
   sortie(ind,:) = Val(2,:);
   fprintf(fid_f, '%s\t', 'B');
   if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
    end
end

indice_trouve = strfind('S',param);
if ~isempty(indice_trouve) 
   ind = ind+1;   
   indice_lecture = indice_lecture+1;
   sortie(ind,:) = Val(3,:);
   fprintf(fid_f, '%s\t', 'S');
   if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
   end
end

indice_trouve = strfind('P1',param);
if ~isempty(indice_trouve) 
   ind = ind+1;   
   indice_lecture = indice_lecture+1; 
   sortie(ind,:) = Val(4,:);
   fprintf(fid_f, '%s\t', 'P1');
   if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
   end
   indice_lecture = indice_lecture+1; 
end

indice_trouve = strfind('P2',param);
if ~isempty(indice_trouve) 
   ind = ind+1;   
   indice_lecture = indice_lecture+1;
   sortie(ind,:) = Val(5,:);
   fprintf(fid_f, '%s\t', 'P2');
   if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
   end
   indice_lecture = indice_lecture+1; 
end

indice_trouve = strfind('C',param);
if ~isempty(indice_trouve)
   ind = ind+1;
   indice_lecture = indice_lecture+1;
   sortie(ind,:) = Val(6,:);
   fprintf(fid_f, '%s\t', 'C');
   if indice_trouve ~= indice_lecture
        chgt_ordre = 1;
   end
end

if chgt_ordre == 1
   msg = sprintf('Attention !\nL''ordre des paramtres en sortie (.lev) sera diffrent de celui spcifi\net respectera l''ordre par dfaut (A,B,S,P1,P2,C)');
   msgbox(msg,'Info');
end

fprintf(fid_f, '\n');

%On sauve les resultats
if ind == 1
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\n', sortie(1,i));
    end
elseif ind == 2
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i));
    end
elseif ind == 3
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i));
    end
elseif ind == 4
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i), sortie(4,i));
    end
elseif ind == 5
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n', sortie(1,i), sortie(2,i), sortie(3,i), sortie(4,i), sortie(5,i));
    end
elseif ind == 6
    for i=1:NbLignes
        fprintf(fid_f, '%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\t%2.4f\n',sortie(1,i),sortie(2,i),sortie(3,i),sortie(4,i),sortie(5,i),sortie(6,i));
    end
end

msg = ['Fichier de paramtres cr : ' nomfich_out];
disp(msg);

fclose(fid_f);
