% [signal, temps, Fe] = ouv_riff(nom_riff);
% 
% Lecture d'un fichier en format RIFF
% 
% 
% Entres: 
%   nom_RIFF : nom du fichier (avec son extension implicite)
%   [EVA_WA1, EVA_TPS1, EVA_FECH1] = ouv_riff('m\data\eva\tom001.wa1');
% Sorties:
%   signal : signal dans l'unit spcifie dans les enttes
%       
% 
% Refait par CS le 21/11/2003 pour TRAP
% Derniere modif : CS le 13/09/17

function [signal, temps, fe_sgl] = ouv_riff(nom_riff);

fid = fopen(nom_riff);

if (fid == -1)
   chaine_erreur = ['Fichier EVA : ' nom_riff ' non trouv !'];
   errordlg(chaine_erreur, 'Message', 'on');
   signal = [];
   temps = [];
   fe_sgl = 0;
   return;
end

% Entte global

id = fscanf(fid,'%c',4);
if ~strcmp(id, 'RIFF') error('lire_RIFF : fichier non RIFF'); end
size = fread(fid,1,'ulong');
form = fscanf(fid,'%c',4);
if ~strcmp(form, 'WSIG') error('lire_RIFF : fichier non EVA'); end

% Signal Description : SIG_DESC
sub_id2 = fscanf(fid,'%c',4);
if ~strcmp(sub_id2, 'sdsc') error('lire_RIFF : fichier sans SIG_DESC'); end
size_id2 = fread(fid,1,'ulong');

sdsc.size_sgl = fread(fid,1,'ulong');
sdsc.acronym = deblank(fscanf(fid,'%c',4));
sdsc.par_name = deblank(fscanf(fid,'%c',80));
sdsc.unit_name = deblank(fscanf(fid,'%c',16));
sdsc.nbsampl = fread(fid,1,'ulong');
fe_sgl = fread(fid,1,'ulong');
sdsc.smax = fread(fid,1,'int16');
sdsc.smin = fread(fid,1,'int16');
sdsc.cmax = fread(fid,1,'int16');
sdsc.czero = fread(fid,1,'int16');
sdsc.imax = fread(fid,1,'int32');
sdsc.fmax = fread(fid,1,'ulong');

% Setup description ACQ_DESC
sub_id3 = fscanf(fid,'%c',4);
size_id3 = fread(fid,1,'ulong');
if ~strcmp(sub_id3, 'adsc') error('lire_RIFF : fichier sans ACQ_DESC'); end
adsc.struc_size = fread(fid,1,'ulong');
adsc.nch = fread(fid,1,'ushort');
adsc.nsamples = fread(fid,1,'ulong');
adsc.freq = fread(fid,1,'ulong');
adsc.bps = fread(fid,1,'ushort');
adsc.highest = fread(fid,1,'int32');
adsc.lowest = fread(fid,1,'int32');
adsc.zero = fread(fid,1,'int32');
adsc.reccode = fread(fid,1,'ushort');
adsc.recver = fread(fid,1,'ushort');

% Liste des infos
sub_id4 = fscanf(fid,'%c',4);
size_id4 = fread(fid,1,'uint32');
if ~strcmp(sub_id4, 'LIST') error('lire_RIFF : fichier sans INFO'); end
[bid, count] = fscanf(fid,'%c',size_id4);
% count
list.total = bid;

% Donnes ... enfin !
sub_id5 = fscanf(fid,'%c',4);
size_id5 = fread(fid,1,'uint32')/2;
if ~strcmp(sub_id5, 'data') error('lire_RIFF : fichier sans donnees'); end
data.dab = fread(fid,size_id5,'int16');


% Signal en units correctes
Ech_dab = (sdsc.imax + 1e-6*sdsc.fmax) / sdsc.cmax;
signal = (data.dab - sdsc.czero) * Ech_dab;
signal = signal';

%================================
% Calcul des donnes temporelles
%================================
temps = linspace(0,(size_id5-1)/fe_sgl,size_id5);

%=====================
% Fermeture du fichier
%=====================
fclose(fid);
