% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : rep_max_90dechute.m
% Source : Matlab
% Auteur : Lucie 
% Date : 19.12.03
%
% Modifi par CS le 25.03.04 :
% Contenu : Repre 90% du max et 10% du min sur un signal
% Les marqueurs seront des curseurs de couleur orang.
%
% Modifi par CS le 15/02/18 :
%       ajout du mode reperage du tps  20% du max rep_20pc_max, uniquement
%       sur signaux EMA
%
% Utilisation : placer le curseur de gauche avant le max et le curseur de droite apres le min 
%
% Sauvegarde des variables suivantes :
%   'vmax'
%   'vmin'
%   'chute'
%   'chute_90'
%   '20pc_max' : 20% du max
%   'chute_10_deb' : 1er minimum local
%   'chute_10_fin' : dernier minimum local
%   'tps_90'
%   'tps_10' : calcul a partir du 1er minimum local
%   'tps_10_apresy_deb' : calcul a partir de chute_10_deb
%   'tps_10_apresy_fin' : calcul a partir de chute_10_fin
%
% Ces variables sont stockes dans un fichier ASCII (.mem) 
% ayant comme racine le nom du fichier WAV associ
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function rep_max_90dechute(sig,fech,tps)

global REP_SEUIL COULEUR_MAX COULEUR_MIN ACOU_NOM_FIC 

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : rep_max_90dechute(signal, Fe, tps)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

% Teste s'il y a un graphique dans la fenetre
%============================================
graph = findobj(gcf,'Type','axes');

% On cherche le tire du subplot en green
texte = findobj(gca,'Type','text','Color',[0 1 0]); %recherche texte green   

if ~isempty(texte)
    nom_subplot = get(texte,'string');
end

%initialisation 
pic_pal = [];
vmax = [];
dixpourcent = [];
tps_90 = [];
tps_10 = [];
tps_10_apresy=[];
j=1;
x=[];
val_max=[];
val_min=[];
chute=[];

% Calcule la derive du signal
der_sig = calc_vit(sig,fech);

% Recherche des passages par zro de la drivee
% En fait on prend toutes les valeurs dont la valeur absolue est
% infrieure au seuil.
%REP_SEUIL = 20;
borne_sup = max(abs(der_sig));
borne_inf = min(abs(der_sig));
seuil = (borne_sup - borne_inf)/REP_SEUIL;
ind_z = find(abs(der_sig) <= seuil);

% Dtermination des maxima
% On commence  2 car la premire valeur de la vitesse est toujours nulle
for i=2 : (length(sig)-1)
  val = sig(i);
  if val > sig(i+1)
    if val >= sig(i-1)
        if ~isempty(val)
            vmax = [vmax, i];
            val_max = [val_max, val];
        end
        %   elseif val == sig(i-1)
        %if ~isempty(val)
        %    vmax = [vmax, i];
        %    val_max = [val_max, val];
        %end
    end
  elseif val > sig(i-1)
      if val == sig(i+1)
         if ~isempty(val)
            vmax = [vmax, i];
            val_max = [val_max, val];
        end
      end
  end
end

%recherche du minimum:
min_trouve = [];
% Dtermination des minimas
% On commence  2 car la premire valeur de la vitesse est toujours nulle

for k=2 : (length(sig)-1)
  val = sig(k);
       if val < sig(k+1)
           if val <= sig(k-1)
              if ~isempty(val)
                min_trouve = [min_trouve, k];
                val_min = [val_min, val];
              end
              %elseif val == sig(k-1)
              %if ~isempty(val)
              %  min_trouve = [min_trouve, k];
              %  val_min = [val_min, val];
              %end
           end
       elseif val < sig(k-1)
           if val == sig(k+1)
              if ~isempty(val)
                min_trouve = [min_trouve, k];
                val_min = [val_min, val];
              end
           end
       end
   
end

valeur_max = -100000;
valeur_min = 100000;

for i=1:length(val_max)
    if val_max(1,i) > valeur_max
        valeur_max = val_max(1,i);
    end
end

for i=1:length(val_min)
    if val_min(1,i) < valeur_min
        valeur_min = val_min(1,i);
    end
end
%valeur_min=0
%chute = valeur_max-valeur_min;
%chute_90 = valeur_max-chute*0.1;
%chute_10 = valeur_min+chute*0.1;

% Modif CS
% ATTENTION : ne marche pas tjs
% chute = val_max(1,1)-val_min(1,1);
% chute_90 = val_max(1,1)-chute*0.1;
% chute_10 = val_min(1,1)+chute*0.1;
chute = valeur_max-valeur_min;
chute_90 = valeur_max-chute*0.1;
chute_10 = valeur_min+chute*0.1;

%recherche du 90%
for j=2:(length(sig)-1)
      val = sig(j);
      if (val > chute_90) && (sig(j+1) < chute_90) %le 90% de chute est entre les deux points
          %calcul de l'quation de la droite entre ces deux points y = mx + b
          pente=(sig(j+1)-val)/(tps(j+1)-tps(j)); %20ms entre deux points (taux d'chantillonnage)
          b=val-(pente*tps(j));      %b=y-mx
          tps(j);
          %recherche de la valeur de temps x pour le point y correspondant a max-90%
          tps_90 =(chute_90-b)/pente;    %x=(y-b)/m
          chute_90;
      end
  
end

%recherche du 10%
for j=2:(length(sig)-1)
      val = sig(j);
      if (val > chute_10) && (sig(j+1) < chute_10) %le 10% de chute est entre les deux points
          %calcul de l'quation de la droite entre ces deux points y = mx + b
          pente=(sig(j+1)-val)/(tps(j+1)-tps(j)); %20ms entre deux points (taux d'chantillonnage)
          b=val-(pente*tps(j));      %b=y-mx
          tps(j);
          %recherche de la valeur de temps x pour le point y correspondant a max-10%
          tps_10=(chute_10-b)/pente;    %x=(y-b)/m
          chute_10;
      end
  
end

%recherche des 10% suivant le minimum du y  partir du 1er minimum local
% for w=2:(length(sig)-1)
%       val = sig(w);
%       if (val < chute_10) && (sig(w+1) > chute_10) %le 10% est entre les deux points
%           %calcul de l'quation de la droite entre ces deux points y = mx + b
%           pente=(sig(w+1)-val)/(tps(w+1)-tps(w)); %20ms entre deux points (taux d'chantillonnage)
%           b=val-(pente*tps(w));      %b=y-mx
%           tps(w);
%           %recherche de la valeur de temps x pour le point y correspondant a max-10%
%           tps_10_apresy =(chute_10-b)/pente;    %x=(y-b)/m
%       end
%   
% end
% 
% chute_10_fin = val_min(1,length(val_min))+chute*0.1;

%recherche des 10% suivant le minimum du y  partir du dernier minimum local
% for w=2:(length(sig)-1)
%       val = sig(w);
%       if (val < chute_10_fin) && (sig(w+1) > chute_10_fin) %le 10% est entre les deux points
%           %calcul de l'quation de la droite entre ces deux points y = mx + b
%           pente=(sig(w+1)-val)/(tps(w+1)-tps(w)); %20ms entre deux points (taux d'chantillonnage)
%           b=val-(pente*tps(w));      %b=y-mx
%           tps(w);
%           %recherche de la valeur de temps x pour le point y correspondant a max-10%
%           tps_10_apresy_fin =(chute_10_fin-b)/pente;    %x=(y-b)/m
%       end
%   
% end

% Ajoute le marquage des plateaux
% vmax = [vmax,pic_pal];

% Affichage
% Attention, ne pas modifier le code de couleur, 
% sinon l'effacage des min-max ne marchera plus.
% cf. eff_minmaxppz.m
hsub = subplot(gca);
limY = get(hsub,'Ylim');
hold on;
line([tps_90 tps_90],limY,'Color', COULEUR_MAX); %sort of orange
line([tps_10 tps_10],limY,'Color', COULEUR_MIN); %sort of cyan
%line([tps_10_apresy tps_10_apresy],limY,'Color', COULEUR_MIN); %sort of cyan
% line([tps_10_apresy_fin tps_10_apresy_fin],limY,'Color', COULEUR_MIN); %sort of cyan
hold off;

% sauvegarde des valeurs ds un fichier ASCII
% on definit un nom de fichier (.txt) de sortie a partir du fichier wav
nom_out_mem = [ACOU_NOM_FIC(1:length(ACOU_NOM_FIC)-3) 'mem'];

% Ouverture du fichier en criture
%=================================
fid = fopen(nom_out_mem,'a');

if fid == -1 
  errordlg(' Impossible de crer le fichier MEM (.mem) ! ','Erreur','on');
  return;
else

if ~exist(nom_out_mem,'file')
    % Ecriture du nom et de la date de cration
    %======================================
    fprintf(fid,'Fichier de mesure des valeurs du MEM issu de TRAP \n');
    fprintf(fid,'Mesures extraites de : %s pour le fichier %s \n', nom_subplot, ACOU_NOM_FIC(1:length(ACOU_NOM_FIC)-4));
    fprintf(fid,'cr le %s\n', date);
    fprintf(fid,'%s\t%s\t%s\t%s\t%s\t%s\t%s\n', 'vmax','vmin','chute','chute_90','chute_10_deb','tps_90','tps_10_deb');
end

% Ecriture des variables
%======================================
% fprintf(fid,'%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n', 'vmax','vmin','chute','chute_90','chute_10_deb','chute_10_fin','tps_90','tps_10_deb','tps_10_apresy_deb','tps_10_apresy_fin');
% fprintf(fid,'%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\n', valeur_max,valeur_min,chute,chute_90,chute_10,chute_10_fin,tps_90,tps_10,tps_10_apresy,tps_10_apresy_fin);
fprintf(fid,'%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\t%2.5f\n', valeur_max,valeur_min,chute,chute_90,chute_10,tps_90,tps_10);
fclose(fid);
end

% sauvegarde des valeurs ds un fichier mat
%nom_out_mat = [ACOU_NOM_FIC(1:length(ACOU_NOM_FIC)-3) 'mat'];
%vmax = val_max(1,1);
%vmin = val_min(1,1);
%eval(['save ' nom_out_mat ' vmax vmin chute chute_90 chute_10 tps_90 tps_10 tps_10_apresy'])

msg = ['Fichier de mesures (.mem) du MEM cr : ' nom_out_mem];
disp(msg);
%msg = ['Fichier de mesures (.mat) du MEM cr : ' nom_out_mat];
%disp(msg);
