% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : rep_ppz.m
% Source : Matlab
% Auteur : H. Loevenbruck
% Date : 26.10.99
% Contenu : Repre les passages par zro d'un signal
% Ils seront marqus par des curseurs de couleur 
% verdatre.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function rep_ppz(sig,fech,tps)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 3
   chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : rep_ppz(signal, Fe, tps)');
   errordlg(chaine_erreur, 'Erreur', 'on');
   return;
end

global REP_SEUIL ACOU_TYP_FIC COULEUR_ZERO
%initialisation 
pic_pal = [];

% Recherche des passages par zro du signal
% En fait on prend toutes les valeurs dont la valeur absolue est
% infrieure au seuil.
borne_sup = max(abs(sig));
borne_inf = min(abs(sig));
seuil = (borne_sup - borne_inf)/REP_SEUIL;
ind_z = find(abs(sig) <= seuil);

ppz = [];

% Dtermination des passages par zro
for i=1 : length(ind_z)
  ind_s = ind_z(i);
  if ind_s < length(sig)
    % Si le signal  l'indice prcdent est ngatif et
    % s'il est positif  l'indice suivant, alors l'indice courant
    % correspond  un passage par zro du signal (et reciproquement)
    if ind_s > 1
      if ((sig(ind_s-1) < 0) && (sig(ind_s+1) > 0)) || ((sig(ind_s-1) > 0) && (sig(ind_s+1) < 0))
        if ~isempty(ppz)
	  lppz = length(ppz);
	  % Si on obtient 2 indices conscutifs correspondant  un meme
	  % passage par zro, il faut prendre celui pour lequel le signal est 
          % le + proche de zro
	  if ind_s == ppz(lppz)+1
	    % Si l'indice courant donne le signal le + proche de zro
	    if abs(sig(ind_s)) < abs(sig(ind_s-1))
	      % On retire l'indice prcdent du vecteur ppz
	      ppz = ppz(1:lppz-1);
	      % On ajoute l'indice courant
	      ppz = [ppz,ind_s];
	    end
	    % Sinon on ne change rien 
	  else
	    % S'ils ne sont pas conscutifs on ajoute l'indice courant 
	    ppz = [ppz,ind_s];
	  end
        else
	  % Si ppz est vide on ajoute l'indice courant
	  ppz = [ppz,ind_s];
        end
      end
    end
  end
end

% Cas d'un signal EPG
if strcmp(ACOU_TYP_FIC,'EPG')
  % Dtermination des paliers
  plateau = find(sig == 0);
  k=2;
  while k < length(plateau)
    clear palier;
    palier = [];
    % On est dans un plateau tant que les indices se suivent
    while k < length(plateau)-1
      if plateau(k)+1 == plateau(k+1)
	palier = [palier,plateau(k)];
	k = k+1;
      else  
	return;
      end
    end
    % On marque le premier indice de chaque plateau
    if ~isempty(palier)
      palier = [palier,plateau(k)];
      % On a un plateau ppz lorsque le signal est ngatif avant le
      % plateau et positif aprs (et reciproquement)
      if ((sig(palier(1)-1) < 0) && (sig(palier(length(palier))+1)) > 0) || ((sig(palier(1)-1) > 0) && (sig(palier(length(palier))+1) < 0))
	pic_pal = [pic_pal,palier(1)];
      end
    else
      k = k+1;
    end
  end
end

% Ajoute le marquage des plateaux
ppz = [ppz, pic_pal];

% Affichage
% Attention, ne pas modifier le code de couleur, 
% sinon l'effacage des min-max-ppz ne marchera plus.
% cf. eff_minmaxppz.m
hsub = subplot(gca);
limY = get(hsub,'Ylim');
hold on;
for n=1 : length(ppz)
  line([tps(ppz(n)) tps(ppz(n))],limY,'Color', COULEUR_ZERO); %sort of green
end
hold off;


