% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : trap.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Modifi par H. Loevenbruck 29.09.99
% Modifi par CS le 18/03/03 :
%       Passage  10 bobines
% Modifi par CS le 25/11/03 :
%       Ajout des fichiers EVA (RIFF)
% Modifi par CS le 05/07/06 :
%       Ajout des fichiers EGG (DCF)
%
% Modifi par CS le 07/01/16 :
%       Passage en 3D
%
% Modifi par CS le 15/02/18 :
%       ajout du mode reperage du tps  20% du max rep_20pc_max, uniquement
%       sur signaux EMA
%
% Contenu : Dclaration et initialisation 
%           des variables globales
%           puis lancement de l'application.
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

% Definir la couleur noire par defaut
colordef black

% Dclaration des variables globales
%===================================

% Nom et type du fichier de donnes acoustiques
global ACOU_NOM_FIC ACOU_NOM_AFFIC ACOU_TYP_FIC

% Nom du fichier de donnes de mesures
global MES_NOM_FIC

% Signaux
global ACOU_SIG ACOU_SIG_CUT EMA_SIG EPG_SIG EVA_SIG

% Valeurs temporelles
global ACOU_TPS ACOU_TPS_CUT EMA_TPS EPG_TPS MES_TPS EVA_TPS1 EVA_TPS2 EVA_TPS_INT

% Frquences d'chantillonnage
global ACOU_FECH EMA_FECH EPG_FECH MES_FECH EVA_FECH1 EVA_FECH2 FE_ACTIF EVA_FECH_INT

% Fitrage Passe Bas par Chebyshev
global CHEBY_FREQ_COUP

% Traitements acoustiques
global ACOU_FEN_TMP ACOU_LONG_FEN ACOU_OVER_FEN 
global ACOU_STEP_FRM ACOU_LENGTH_FRM
global ACOU_TPS_FRM ACOU_DATA_FRM
global ACOU_CALC_FFT ACOU_ORD_FFT 
global ACOU_CALC_LPC ACOU_ORD_LPC 
global ACOU_CALC_CEPS ACOU_CEPS_VIS 
global ACOU_SPECTRO

% Traitements EMA
global EMA_FLAG EMA_BOB1 EMA_BOB2 EMA_BOB3 EMA_BOB4 EMA_ECHELLE 
global EMA_BOB5 EMA_BOB6 EMA_BOB7 EMA_BOB8 EMA_BOB9 EMA_BOB10 EMA_BOB11 EMA_BOB12 EMA_BOB13 EMA_BOB14 EMA_BOB15 EMA_BOB16
global EMA_X1 EMA_X2 EMA_X3 EMA_X4 EMA_X5 EMA_X6 EMA_X7 EMA_X8 EMA_X9 EMA_X10 EMA_X11 EMA_X12 EMA_X13 EMA_X14 EMA_X15 EMA_X16
global EMA_Y1 EMA_Y2 EMA_Y3 EMA_Y4 EMA_Y5 EMA_Y6 EMA_Y7 EMA_Y8 EMA_Y9 EMA_Y10 EMA_Y11 EMA_Y12 EMA_Y13 EMA_Y14 EMA_Y15 EMA_Y16 
global EMA_Z1 EMA_Z2 EMA_Z3 EMA_Z4 EMA_Z5 EMA_Z6 EMA_Z7 EMA_Z8 EMA_Z9 EMA_Z10 EMA_Z11 EMA_Z12 EMA_Z13 EMA_Z14 EMA_Z15 EMA_Z16
global EMA_COUP_SAG EMA_NUM_SAG EMA_COUP_SAG_3D
global EMA_PAL_X EMA_PAL_Y EMA_PAL_Z EMA_PALAIS EMA_BOB_PAL EMA_FIC_PAL
global EMA_TILT
global EMA_TILT_B1 EMA_TILT_B2 EMA_TILT_B3 EMA_TILT_B4 EMA_TILT_B5 
global EMA_TILT_B6 EMA_TILT_B7 EMA_TILT_B8 EMA_TILT_B9 EMA_TILT_B10 

% Traitements EPG
global EPG_NOM_LOC EPG_NB_ELEC EPG_POS_ELEC 
global EPG_PAL_SIMPLE EPG_PAL_SERIE EPG_NB_PAL EPG_PAL_FEN
global EPG_REGIONS EPG_CHANNEL EPG_NOM_REG 
global EPG_NB_CONS EPG_NOM_CONS EPG_DATA_CONS 

% Traitements EVA
global EVA_WA1 EVA_WA2 EVA_F0 EVA_EGG EVA_OAF EVA_NAF EVA_PR1 EVA_PR2 EVA_INT EVA_AUX
global TPS_EVA_ACTIF FLAG_EVA NB_EVA

% Traitements EGG
global EGG_1 EGG_2 EGG_3 EGG_4 NB_EGG
global EGG_NOM1 EGG_NOM2 EGG_NOM3 EGG_NOM4
global EGG_TPS EGG_FECH

% Traitements mesure gnrale
global MES_NB MES_NOM MES_DATA CURSEUR

% Niveaux d'tiquettes
global NIV_ETIQ TYPE_ETIQ COULEUR_ETIQ STYLE_ETIQ

% Reprage min max pour EMA, EPG et Mesure Gnrale
global REP_SEUIL COULEUR_MIN COULEUR_MAX COULEUR_ZERO COULEUR_MOY COULEUR_20PC
global COULEUR_GRAPH COULEUR_FOND COULEUR_ACTIVE COULEUR_AXES COULEUR_POINTEUR COULEUR_TITRE_FEN

% Fenetre principale
global NUM_FEN INDEX NB_LIG NB_COL SUPERPOSE

% Fenetre synchrone
global NUM_SYNC IND_SYNC COL_SYNC 

% Zoom
global FLAG_ZOOM ZOOM_PREC_DEB ZOOM_PREC_FIN NB_ZOOM

% Couleur de visualisation des bobines
% global COUL_B1 COUL_B2 COUL_B3 COUL_B4 COUL_B5 COUL_B6 COUL_B7 COUL_B8 COUL_B9 COUL_B10
% global COUL_B11 COUL_B12 COUL_B13 COUL_B14 COUL_B15 COUL_B16

% Initialisation des variables globales
%======================================
ACOU_NOM_FIC = [];
ACOU_NOM_AFFIC = [];

ACOU_TYP_FIC = [];

MES_NOM_FIC = [];

ACOU_SIG = [];
ACOU_SIG_CUT = [];
EMA_SIG = [];
EPG_SIG = [];

ACOU_TPS = [];
ACOU_TPS_CUT = [];
EMA_TPS = [];
EPG_TPS = [];
MES_TPS = [];
EVA_TPS1 = [];
EVA_TPS2 = [];
EVA_TPS_INT = [];

% Acoustique
ACOU_FECH = 22050;
EMA_FECH = 200;
EPG_FECH = 100;
MES_FECH = 50;
EVA_FECH1 = 25000;
EVA_FECH2 = 6250;
EVA_FECH_INT = 12500;

ACOU_LONG_FEN = 128;
ACOU_FEN_TMP = 128;  % specgram prendra Hanning(ACOU_FEN_TMP)
ACOU_OVER_FEN = 64; % ACOU_OVER_FEN is the number of samples the sections of sig overlap

ACOU_STEP_FRM = 0.010; % pas du traitement formantique en s
ACOU_LENGTH_FRM = 0.032; %longueur de la fenetre pour le traitement formantique en s
ACOU_TPS_FRM = [];
ACOU_DATA_FRM = [];

ACOU_CALC_FFT = 0;
ACOU_ORD_FFT = 512;

ACOU_CALC_LPC = 0;
ACOU_ORD_LPC = 22;

ACOU_CALC_CEPS = 0;
ACOU_CEPS_VIS = 4; % locuteur masculin

ACOU_SPECTRO = [];

% EMA
EMA_FLAG = 0;
EMA_BOB1 = 'B1';
EMA_BOB2 = 'B2';
EMA_BOB3 = 'B3';
EMA_BOB4 = 'B4';
EMA_BOB5 = 'B5';
EMA_BOB6 = 'B6';
EMA_BOB7 = 'B7';
EMA_BOB8 = 'B8';
EMA_BOB9 = 'B9';
EMA_BOB10 = '';
EMA_BOB11 = '';
EMA_BOB12 = '';
EMA_BOB13 = '';
EMA_BOB14 = '';
EMA_BOB15 = '';
EMA_BOB16 = '';

EMA_ECHELLE = 1; 
EMA_X1 = [];
EMA_X2 = [];
EMA_X3 = [];
EMA_X4 = [];
EMA_X5 = [];
EMA_X6 = [];
EMA_X7 = [];
EMA_X8 = [];
EMA_X9 = [];
EMA_X10 = [];
EMA_X11 = [];
EMA_X12 = [];
EMA_X13 = [];
EMA_X14 = [];
EMA_X15 = [];
EMA_X16 = [];

EMA_Y1 = [];
EMA_Y2 = [];
EMA_Y3 = [];
EMA_Y4 = [];
EMA_Y5 = [];
EMA_Y6 = [];
EMA_Y7 = [];
EMA_Y8 = [];
EMA_Y9 = [];
EMA_Y10 = [];
EMA_Y11 = [];
EMA_Y12 = [];
EMA_Y13 = [];
EMA_Y14 = [];
EMA_Y15 = [];
EMA_Y16 = [];

EMA_Z1 = [];
EMA_Z2 = [];
EMA_Z3 = [];
EMA_Z4 = [];
EMA_Z5 = [];
EMA_Z6 = [];
EMA_Z7 = [];
EMA_Z8 = [];
EMA_Z9 = [];
EMA_Z10 = [];
EMA_Z11 = [];
EMA_Z12 = [];
EMA_Z13 = [];
EMA_Z14 = [];
EMA_Z15 = [];
EMA_Z16 = [];

EMA_NUM_SAG = 0;
EMA_COUP_SAG = 0;
EMA_COUP_SAG_3D = 0;
EMA_PAL_X = [];
EMA_PAL_Y = [];
EMA_PAL_Z = [];
EMA_PALAIS = [];
EMA_BOB_PAL = 0;
EMA_FIC_PAL = [];
EMA_TILT = 0;
EMA_TILT_B1 = [];
EMA_TILT_B2 = [];
EMA_TILT_B3 = [];
EMA_TILT_B4 = [];
EMA_TILT_B5 = [];
EMA_TILT_B6 = [];
EMA_TILT_B7 = [];
EMA_TILT_B8 = [];
EMA_TILT_B9 = [];
EMA_TILT_B10 = [];

CHEBY_FREQ_COUP = 20;

% EPG
EPG_NOM_LOC = '';
EPG_NB_ELEC = 96;
EPG_POS_ELEC = 0;
EPG_PAL_SIMPLE = 0;
EPG_PAL_SERIE = 0;
EPG_NB_PAL = 3;
EPG_PAL_FEN = 0;
EPG_REGIONS = [];
EPG_CHANNEL = 0;
EPG_NOM_REG = [];
EPG_NB_CONS = 0;
EPG_NOM_CONS = '';
EPG_DATA_CONS = [];

% EVA
EVA_WA1 = [];
EVA_WA2 = [];
EVA_F0 = [];
EVA_EGG = [];
EVA_OAF = [];
EVA_NAF = [];
EVA_PR1 = [];
EVA_PR2 = [];
EVA_INT = [];
EVA_AUX = [];
FLAG_EVA = [];
NB_EVA = 0;
FE_ACTIF = 0;
TPS_EVA_ACTIF = [];

% EGG
% Par dfaut on suppose qu'on n'a que 4 entres EGG
% si plus d'entres, TRAP n'est pas compatible 
NB_EGG = 4; 
EGG_1 = [];
EGG_2 = [];
EGG_3 = [];
EGG_4 = [];
EGG_NOM1 = 'canal1';
EGG_NOM2 = 'canal2';
EGG_NOM3 = 'canal3';
EGG_NOM4 = 'canal4';
EGG_FECH = 50000;
EGG_TPS = [];

MES_NB = 0;
MES_NOM = '';
MES_DATA = [];

NIV_ETIQ = 5;

TYPE_ETIQ(1,1:length('Phontique'))='Phontique';
TYPE_ETIQ(2,1:length('Tonal'))='Tonal';
TYPE_ETIQ(3,1:length('Break Index'))='Break Index';
TYPE_ETIQ(4,1:length('Mismatch'))='Mismatch';
TYPE_ETIQ(5,1:length('Commentaire'))='Commentaire';
TYPE_ETIQ = char(TYPE_ETIQ);

% Initialisation des couleurs des etiquettes.
% Les couleurs pseudo-red sont a proscrire pour ne pas confondre 
% les tiquettes avec le curseur.

for i = 1:NIV_ETIQ 
  COULEUR_ETIQ(i,:) =  (1 - 1/(4*i)) *[0  0.99 0];   %pour conserver des intensites de vert entre 0 et 1
  STYLE_ETIQ(i,1:1) = '-'; % par dfaut : trait plein
end
STYLE_ETIQ = char(STYLE_ETIQ);

REP_SEUIL = 5;
% COULEUR_GRAPH = [1 1 0]; %yellow
% COULEUR_FOND = [0 0 0]; %noir
% COULEUR_AXES = [1 1 1]; % blanc
COULEUR_GRAPH = [0 0 1]; %blue
COULEUR_FOND = [1 1 1]; % blanc
COULEUR_TITRE_FEN = [0 0 0]; %noir
COULEUR_AXES = [0 0 0]; %noir
COULEUR_POINTEUR = [1 0 0]; %red

COULEUR_ACTIVE = [0 1 1]; % cyan
COULEUR_MIN = [0.5 1 0.5]; %sort of green
COULEUR_MAX = [1 0.6 0.2]; %sort of orange
COULEUR_ZERO = [0.5 0.5 0]; %sort of yellow
COULEUR_MOY = [0 1 1]; %sort of cyan
COULEUR_20PC = [.5 0 1]; % sort of purple

% COUL_B1 = [1 1 .5]; % sort of yellow
% COUL_B2 = [0 1 0]; % green
% COUL_B3 = [1 0 0]; % red
% COUL_B4 = [0 0 1]; % blue
% COUL_B5 = [.5 1 1]; % sort of cyan
% COUL_B6 = [1 .5 1]; % sort of magenta
% COUL_B7 = [.5 0 1]; % sort of purple
% COUL_B8 = [1 .5 0]; % sort of orange
% COUL_B9 = [1 1 1]; % white
% COUL_B10 = [.7 .7 .7]; % sort of grey
% COUL_B11 = [.7 .7 .7]; % sort of grey
% COUL_B12 = [.7 .7 .7]; % sort of grey
% COUL_B13 = [.7 .7 .7]; % sort of grey
% COUL_B14 = [.7 .7 .7]; % sort of grey
% COUL_B15 = [.7 .7 .7]; % sort of grey
% COUL_B16 = [.7 .7 .7]; % sort of grey

NUM_FEN = 0;
INDEX = 0;
NB_LIG = 0; 
NB_COL = 0;
SUPERPOSE = 0;
CURSEUR = 1;

NUM_SYNC = 0;
IND_SYNC = 0;
COL_SYNC = 1; 

FLAG_ZOOM = 0;
NB_ZOOM = 1;
ZOOM_PREC_DEB = [];
ZOOM_PREC_FIN = [];

% Lancement de la barre de menus principale
%==========================================
init_menu;
