% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fichier : zoom_in.m
% Source : Matlab
% Auteur : D. Lefebvre
% Date : 21.06.99
% Dernire modification par H. Loevenbruck 12.09.02
% Dernire modification : CS, le 16/01/07
%   passage en 3D
% Dernire modification : CS, le 01/09/16
%   Ajout 16 canaux
%
% Contenu : Effectue un zoom de tous les
%           graphiques se trouvant dans la fenetre
% Attention ne marche bien que si le titre de chaque
% trac est bien crit en vert
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function zoom_in(min,max)

%===============================
% TEST SUR LE NOMBRE D'ARGUMENTS
%===============================

if nargin < 2
    chaine_erreur = sprintf(' Nombre d''arguments insuffisants !\n Syntaxe : zoom_in(instant1, instant2)');
    errordlg(chaine_erreur, 'Erreur', 'on');
    return;
end

global NB_LIG NB_COL INDEX NUM_FEN
global EMA_FECH EMA_COUP_SAG EMA_BOB_PAL EMA_X1 EMA_X2 EMA_X3 EMA_X4 EMA_Y1 EMA_Y2 EMA_Y3 EMA_Y4 EMA_NUM_SAG EMA_PALAIS EMA_ECHELLE
global FLAG_ZOOM CURSEUR

% Rajout CS
global EMA_X5 EMA_X6 EMA_X7 EMA_X8 EMA_X9 EMA_X10 EMA_X11 EMA_X12 EMA_X13 EMA_X14 EMA_X15 EMA_X16
global EMA_Y5 EMA_Y6 EMA_Y7 EMA_Y8 EMA_Y9 EMA_Y10 EMA_Y11 EMA_Y12 EMA_Y13 EMA_Y14 EMA_Y15 EMA_Y16
global EMA_Z1 EMA_Z2 EMA_Z3 EMA_Z4 EMA_Z5 EMA_Z6 EMA_Z7 EMA_Z8 EMA_Z9 EMA_Z10 EMA_Z11 EMA_Z12 EMA_Z13 EMA_Z14 EMA_Z15 EMA_Z16

if NUM_FEN == 0
    errordlg(' Veuillez ouvrir une fenetre principale','Erreur','on');
    return;
end
figure(NUM_FEN);

% Teste s'il y a un graphique dans la fenetre
%============================================
graph = findobj(gcf,'Type','axes');
if isempty(graph)
    errordlg(' Pas de graphique !','Erreur','on');
    return
else
    graph = length(graph);
    
    % Effectue le zoom en changeant l'axe des X
    %===========================================
    
    for i = 1 : graph
        subplot(NB_LIG+1,NB_COL,i);
        % Teste si le subplot contient bien un graphique
        if ~isempty(get(gca, 'Children'))
            
            % effectue le zoom
            ylim = get(gca,'Ylim');
            axis([min max ylim]);
            
            % re-affiche le titre du subplot en green
            texte = findobj(gca,'Type','text','Color',[0 1 0]); %recherche texte green
            
            if ~isempty(texte)
                nom = get(texte,'string');
                titre(nom);
            end
            
            % re-affiche les coordonnes en pseudo-red
            coord = findobj(gca,'Type','text','Color',[0.99 0 0]); %recherche texte en pseudo-red (x, y)
            if ~isempty(coord)
                texte_coord = get(coord, 'string');
                delete(coord);
                text((max-min)/3,ylim(2),texte_coord,'VerticalAlignment','baseline','Color',[0.99 0 0]); %Affiche texte en pseudo-red
            end
            
            % re-affiche F1 si ncessaire
            F1 = findobj(gca,'Type','text','Color',[0.9 0 0.9]); %recherche texte en pseudo-magenta (F1)
            if ~isempty(F1)
                texte_F1 = get(F1, 'string');
                delete(F1);
                text((max-min)/3,ylim(2),texte_F1,'VerticalAlignment','baseline','Color',[0.9 0 0.9]); %Affiche texte en pseudo-magenta
            end
            
            % re-affiche F2 si ncessaire
            F2 = findobj(gca,'Type','text','Color',[0 0.9 0.9]); %recherche texte en pseudo-cyan (F2)
            
            if ~isempty(F2)
                texte_F2 = get(F2, 'string');
                delete(F2);
                text((max-min)/3,ylim(2),texte_F2,'VerticalAlignment','baseline','Color',[0 0.9 0.9]); %Affiche texte en pseudo-cyan
            end
            
            % re-affiche F3 si ncessaire
            F3 = findobj(gca,'Type','text','Color',[0 0.9 0]); %recherche texte en pseudo-green (F3)
            if ~isempty(F3)
                texte_F3 = get(F3, 'string');
                delete(F3);
                text((max-min)/3,ylim(2),texte_F3,'VerticalAlignment','baseline','Color',[0 0.9 0]); %Affiche texte en pseudo-green
            end
            texte = [];
            F1 = [];
            F2 = [];
            F3 = [];
        end
    end
    
    % Effectue le zoom de la coupe sagittale si demande
    %===================================================
    
    if EMA_COUP_SAG
        if EMA_BOB_PAL
            long_ema = length(EMA_X1);
            ind_coup = round([min max].*EMA_FECH+1);   % On recupre les indices de la matrice du signal
            if (ind_coup(1) > long_ema) || (ind_coup(1) < 1)
                errordlg(' Le curseur ne se trouve plus sur le signal !','Attention','on');
                % break;
            else
                if EMA_NUM_SAG == 0
                    EMA_NUM_SAG = figure('Numbertitle','off','Name','Coupe sagittale', 'MenuBar', 'none');
                    uicontrol(EMA_NUM_SAG,'Style','Pushbutton','String','Enregistrer',...
                        'Position',[0 0 80 20],'Callback','ema_enr_pal;');
                end
                figure(EMA_NUM_SAG);
                if isempty(EMA_Z1) % pas de 3D
                    if EMA_BOB_PAL == 1
                        plot(EMA_X1(ind_coup(1):ind_coup(2)),EMA_Y1(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X1(ind_coup(1):ind_coup(2)),EMA_Y1(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 2
                        plot(EMA_X2(ind_coup(1):ind_coup(2)),EMA_Y2(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X2(ind_coup(1):ind_coup(2)),EMA_Y2(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 3
                        plot(EMA_X3(ind_coup(1):ind_coup(2)),EMA_Y3(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X3(ind_coup(1):ind_coup(2)),EMA_Y3(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 4
                        plot(EMA_X4(ind_coup(1):ind_coup(2)),EMA_Y4(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X4(ind_coup(1):ind_coup(2)),EMA_Y4(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 5
                        plot(EMA_X5(ind_coup(1):ind_coup(2)),EMA_Y5(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X5(ind_coup(1):ind_coup(2)),EMA_Y5(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 6
                        plot(EMA_X6(ind_coup(1):ind_coup(2)),EMA_Y6(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X6(ind_coup(1):ind_coup(2)),EMA_Y6(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 7
                        plot(EMA_X7(ind_coup(1):ind_coup(2)),EMA_Y7(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X7(ind_coup(1):ind_coup(2)),EMA_Y7(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 8
                        plot(EMA_X8(ind_coup(1):ind_coup(2)),EMA_Y8(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X8(ind_coup(1):ind_coup(2)),EMA_Y8(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 9
                        plot(EMA_X9(ind_coup(1):ind_coup(2)),EMA_Y9(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X9(ind_coup(1):ind_coup(2)),EMA_Y9(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 10
                        plot(EMA_X10(ind_coup(1):ind_coup(2)),EMA_Y10(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X10(ind_coup(1):ind_coup(2)),EMA_Y10(ind_coup(1):ind_coup(2))];
                        % Ajout 16 canaux
                    elseif EMA_BOB_PAL == 11
                        plot(EMA_X11(ind_coup(1):ind_coup(2)),EMA_Y11(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X11(ind_coup(1):ind_coup(2)),EMA_Y11(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 12
                        plot(EMA_X12(ind_coup(1):ind_coup(2)),EMA_Y12(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X12(ind_coup(1):ind_coup(2)),EMA_Y12(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 13
                        plot(EMA_X13(ind_coup(1):ind_coup(2)),EMA_Y13(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X13(ind_coup(1):ind_coup(2)),EMA_Y13(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 14
                        plot(EMA_X14(ind_coup(1):ind_coup(2)),EMA_Y14(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X14(ind_coup(1):ind_coup(2)),EMA_Y14(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 15
                        plot(EMA_X15(ind_coup(1):ind_coup(2)),EMA_Y15(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X15(ind_coup(1):ind_coup(2)),EMA_Y15(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 16
                        plot(EMA_X16(ind_coup(1):ind_coup(2)),EMA_Y16(ind_coup(1):ind_coup(2)));
                        EMA_PALAIS = [EMA_X16(ind_coup(1):ind_coup(2)),EMA_Y16(ind_coup(1):ind_coup(2))];
                    end
                else % c'est du 3D
                    if EMA_BOB_PAL == 1
                        plot3(EMA_X1(ind_coup(1):ind_coup(2)), EMA_Y1(ind_coup(1):ind_coup(2)), EMA_Z1(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X1(ind_coup(1):ind_coup(2)), EMA_Y1(ind_coup(1):ind_coup(2)), EMA_Z1(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 2
                        plot3(EMA_X2(ind_coup(1):ind_coup(2)), EMA_Y2(ind_coup(1):ind_coup(2)), EMA_Z2(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X2(ind_coup(1):ind_coup(2)), EMA_Y2(ind_coup(1):ind_coup(2)), EMA_Z2(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 3
                        plot3(EMA_X3(ind_coup(1):ind_coup(2)), EMA_Y3(ind_coup(1):ind_coup(2)), EMA_Z3(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X3(ind_coup(1):ind_coup(2)), EMA_Y3(ind_coup(1):ind_coup(2)), EMA_Z3(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 4
                        plot3(EMA_X4(ind_coup(1):ind_coup(2)), EMA_Y4(ind_coup(1):ind_coup(2)), EMA_Z4(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X4(ind_coup(1):ind_coup(2)), EMA_Y4(ind_coup(1):ind_coup(2)), EMA_Z4(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 5
                        plot3(EMA_X5(ind_coup(1):ind_coup(2)), EMA_Y5(ind_coup(1):ind_coup(2)), EMA_Z5(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X5(ind_coup(1):ind_coup(2)), EMA_Y5(ind_coup(1):ind_coup(2)), EMA_Z5(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 6
                        plot3(EMA_X6(ind_coup(1):ind_coup(2)), EMA_Y6(ind_coup(1):ind_coup(2)), EMA_Z6(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X6(ind_coup(1):ind_coup(2)), EMA_Y6(ind_coup(1):ind_coup(2)), EMA_Z6(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 7
                        plot3(EMA_X7(ind_coup(1):ind_coup(2)), EMA_Y7(ind_coup(1):ind_coup(2)), EMA_Z7(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X7(ind_coup(1):ind_coup(2)), EMA_Y7(ind_coup(1):ind_coup(2)), EMA_Z7(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 8
                        plot3(EMA_X8(ind_coup(1):ind_coup(2)), EMA_Y8(ind_coup(1):ind_coup(2)), EMA_Z8(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X8(ind_coup(1):ind_coup(2)), EMA_Y8(ind_coup(1):ind_coup(2)), EMA_Z8(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 9
                        plot3(EMA_X9(ind_coup(1):ind_coup(2)), EMA_Y9(ind_coup(1):ind_coup(2)), EMA_Z9(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X9(ind_coup(1):ind_coup(2)), EMA_Y9(ind_coup(1):ind_coup(2)), EMA_Z9(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 10
                        plot3(EMA_X10(ind_coup(1):ind_coup(2)), EMA_Y10(ind_coup(1):ind_coup(2)), EMA_Z10(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X10(ind_coup(1):ind_coup(2)), EMA_Y10(ind_coup(1):ind_coup(2)), EMA_Z10(ind_coup(1):ind_coup(2))];
                        % Ajout 16 canaux
                    elseif EMA_BOB_PAL == 11
                        plot3(EMA_X11(ind_coup(1):ind_coup(2)), EMA_Y11(ind_coup(1):ind_coup(2)), EMA_Z11(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X11(ind_coup(1):ind_coup(2)), EMA_Y11(ind_coup(1):ind_coup(2)), EMA_Z11(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 12
                        plot3(EMA_X12(ind_coup(1):ind_coup(2)), EMA_Y12(ind_coup(1):ind_coup(2)), EMA_Z12(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X12(ind_coup(1):ind_coup(2)), EMA_Y12(ind_coup(1):ind_coup(2)), EMA_Z12(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 13
                        plot3(EMA_X13(ind_coup(1):ind_coup(2)), EMA_Y13(ind_coup(1):ind_coup(2)), EMA_Z13(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X13(ind_coup(1):ind_coup(2)), EMA_Y13(ind_coup(1):ind_coup(2)), EMA_Z13(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 14
                        plot3(EMA_X14(ind_coup(1):ind_coup(2)), EMA_Y14(ind_coup(1):ind_coup(2)), EMA_Z14(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X14(ind_coup(1):ind_coup(2)), EMA_Y14(ind_coup(1):ind_coup(2)), EMA_Z14(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 15
                        plot3(EMA_X15(ind_coup(1):ind_coup(2)), EMA_Y15(ind_coup(1):ind_coup(2)), EMA_Z15(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X15(ind_coup(1):ind_coup(2)), EMA_Y15(ind_coup(1):ind_coup(2)), EMA_Z15(ind_coup(1):ind_coup(2))];
                    elseif EMA_BOB_PAL == 16
                        plot3(EMA_X16(ind_coup(1):ind_coup(2)), EMA_Y16(ind_coup(1):ind_coup(2)), EMA_Z16(ind_coup(1):ind_coup(2)));
                        view(0,90);
                        EMA_PALAIS = [EMA_X16(ind_coup(1):ind_coup(2)), EMA_Y16(ind_coup(1):ind_coup(2)), EMA_Z16(ind_coup(1):ind_coup(2))];
                    end
                end
                
                grid on;
                buf = sprintf('Contour du palais entre t =%6.2f et %6.2f s',min,max);
                title(buf,'Color','g'); %crit texte en green
                if EMA_ECHELLE == 1
                    echelle = 'cm';
                else
                    echelle = 'mm';
                end
                xlabel(['X ',echelle]);
                ylabel(['Y ',echelle]);
                axis('equal');
            end
        end
    end
end

figure(NUM_FEN);
subplot(NB_LIG+1,NB_COL,INDEX); % pour s'assurer que le gca est correct

if CURSEUR
    maj_curseur; % mise  jour des bornes du curseur
    curseur(min+(max-min)/2);
end

FLAG_ZOOM = 1;
